#!/bin/ksh

daemon="${TRUEPREFIX}/bin/pgpool"
daemon_user="_pgpool"

. /etc/rc.d/rc.subr

rc_pre() {
	/usr/bin/install -d -o _pgpool /var/run/pgpool
}

rc_stop() {
	${daemon} -m s stop || ${daemon} -m f stop
}

rc_reload() {
	${daemon} reload
}

rc_cmd $1
