#!/bin/ksh

daemon="${TRUEPREFIX}/bin/vmetrics"
daemon_flags="-storageDataPath '${LOCALSTATEDIR}/db/vmetrics/'"
daemon_user="_vmetrics"
daemon_logger="daemon.info"

. /etc/rc.d/rc.subr

rc_bg=YES
rc_reload=NO

rc_cmd $1
