#!/bin/ksh

daemon="${TRUEPREFIX}/bin/navidrome"
daemon_user="_navidrome"
daemon_flags="-a localhost --datafolder ${VARBASE}/navidrome --musicfolder ${VARBASE}/navidrome/music"

. /etc/rc.d/rc.subr

rc_bg=YES
rc_reload=NO

rc_cmd $1
