MODCARGO_CRATES +=	addr2line	0.19.0	# Apache-2.0 OR MIT
MODCARGO_CRATES +=	adler	1.0.2	# 0BSD OR MIT OR Apache-2.0
MODCARGO_CRATES +=	aes	0.6.0	# MIT OR Apache-2.0
MODCARGO_CRATES +=	aes-ctr	0.6.0	# MIT OR Apache-2.0
MODCARGO_CRATES +=	aes-soft	0.6.4	# MIT OR Apache-2.0
MODCARGO_CRATES +=	aesni	0.10.0	# MIT OR Apache-2.0
MODCARGO_CRATES +=	ahash	0.8.3	# MIT OR Apache-2.0
MODCARGO_CRATES +=	aho-corasick	0.7.20	# Unlicense OR MIT
MODCARGO_CRATES +=	alsa	0.6.0	# Apache-2.0/MIT
MODCARGO_CRATES +=	alsa-sys	0.3.1	# MIT
MODCARGO_CRATES +=	android_system_properties	0.1.5	# MIT/Apache-2.0
MODCARGO_CRATES +=	async-trait	0.1.66	# MIT OR Apache-2.0
MODCARGO_CRATES +=	autocfg	1.1.0	# Apache-2.0 OR MIT
MODCARGO_CRATES +=	backtrace	0.3.67	# MIT OR Apache-2.0
MODCARGO_CRATES +=	base64	0.13.1	# MIT/Apache-2.0
MODCARGO_CRATES +=	base64	0.21.0	# MIT OR Apache-2.0
MODCARGO_CRATES +=	bindgen	0.61.0	# BSD-3-Clause
MODCARGO_CRATES +=	bitflags	1.3.2	# MIT/Apache-2.0
MODCARGO_CRATES +=	block	0.1.6	# MIT
MODCARGO_CRATES +=	block-buffer	0.9.0	# MIT OR Apache-2.0
MODCARGO_CRATES +=	block-buffer	0.10.4	# MIT OR Apache-2.0
MODCARGO_CRATES +=	bumpalo	3.12.0	# MIT/Apache-2.0
MODCARGO_CRATES +=	bytecount	0.6.3	# Apache-2.0/MIT
MODCARGO_CRATES +=	byteorder	1.4.3	# Unlicense OR MIT
MODCARGO_CRATES +=	bytes	1.4.0	# MIT
MODCARGO_CRATES +=	cc	1.0.79	# MIT OR Apache-2.0
MODCARGO_CRATES +=	cesu8	1.1.0	# Apache-2.0/MIT
MODCARGO_CRATES +=	cexpr	0.6.0	# Apache-2.0/MIT
MODCARGO_CRATES +=	cfg-if	1.0.0	# MIT/Apache-2.0
MODCARGO_CRATES +=	chrono	0.4.23	# MIT/Apache-2.0
MODCARGO_CRATES +=	cipher	0.2.5	# MIT OR Apache-2.0
MODCARGO_CRATES +=	clang-sys	1.6.0	# Apache-2.0
MODCARGO_CRATES +=	clap	4.1.8	# MIT OR Apache-2.0
MODCARGO_CRATES +=	clap_complete	4.1.4	# MIT OR Apache-2.0
MODCARGO_CRATES +=	clap_lex	0.3.2	# MIT OR Apache-2.0
MODCARGO_CRATES +=	clap_mangen	0.2.9	# MIT OR Apache-2.0
MODCARGO_CRATES +=	clipboard	0.5.0	# MIT / Apache-2.0
MODCARGO_CRATES +=	clipboard-win	2.2.0	# MIT
MODCARGO_CRATES +=	codespan-reporting	0.11.1	# Apache-2.0
MODCARGO_CRATES +=	combine	4.6.6	# MIT
MODCARGO_CRATES +=	cookie	0.16.2	# MIT OR Apache-2.0
MODCARGO_CRATES +=	cookie_store	0.19.0	# MIT/Apache-2.0
MODCARGO_CRATES +=	core-foundation	0.9.3	# MIT / Apache-2.0
MODCARGO_CRATES +=	core-foundation-sys	0.8.3	# MIT / Apache-2.0
MODCARGO_CRATES +=	coreaudio-rs	0.10.0	# MIT/Apache-2.0
MODCARGO_CRATES +=	coreaudio-sys	0.2.11	# MIT
MODCARGO_CRATES +=	cpal	0.13.5	# Apache-2.0
MODCARGO_CRATES +=	cpufeatures	0.2.5	# MIT OR Apache-2.0
MODCARGO_CRATES +=	crossbeam-channel	0.5.7	# MIT OR Apache-2.0
MODCARGO_CRATES +=	crossbeam-utils	0.8.15	# MIT OR Apache-2.0
MODCARGO_CRATES +=	crypto-common	0.1.6	# MIT OR Apache-2.0
MODCARGO_CRATES +=	crypto-mac	0.11.1	# MIT OR Apache-2.0
MODCARGO_CRATES +=	ctr	0.6.0	# MIT OR Apache-2.0
MODCARGO_CRATES +=	cursive	0.20.0	# MIT
MODCARGO_CRATES +=	cursive_buffered_backend	0.6.1	# MIT
MODCARGO_CRATES +=	cursive_core	0.3.7	# MIT
MODCARGO_CRATES +=	cxx	1.0.92	# MIT OR Apache-2.0
MODCARGO_CRATES +=	cxx-build	1.0.92	# MIT OR Apache-2.0
MODCARGO_CRATES +=	cxxbridge-flags	1.0.92	# MIT OR Apache-2.0
MODCARGO_CRATES +=	cxxbridge-macro	1.0.92	# MIT OR Apache-2.0
MODCARGO_CRATES +=	darling	0.13.4	# MIT
MODCARGO_CRATES +=	darling	0.14.3	# MIT
MODCARGO_CRATES +=	darling_core	0.13.4	# MIT
MODCARGO_CRATES +=	darling_core	0.14.3	# MIT
MODCARGO_CRATES +=	darling_macro	0.13.4	# MIT
MODCARGO_CRATES +=	darling_macro	0.14.3	# MIT
MODCARGO_CRATES +=	dbus	0.9.7	# Apache-2.0/MIT
MODCARGO_CRATES +=	dbus-tree	0.9.2	# Apache-2.0/MIT
MODCARGO_CRATES +=	derive-new	0.5.9	# MIT
MODCARGO_CRATES +=	digest	0.9.0	# MIT OR Apache-2.0
MODCARGO_CRATES +=	digest	0.10.6	# MIT OR Apache-2.0
MODCARGO_CRATES +=	dirs-next	1.0.2	# MIT OR Apache-2.0
MODCARGO_CRATES +=	dirs-next	2.0.0	# MIT OR Apache-2.0
MODCARGO_CRATES +=	dirs-sys-next	0.1.2	# MIT OR Apache-2.0
MODCARGO_CRATES +=	downcast-rs	1.2.0	# MIT/Apache-2.0
MODCARGO_CRATES +=	encoding_rs	0.8.32	# (Apache-2.0 OR MIT) AND BSD-3-Clause
MODCARGO_CRATES +=	enum-map	2.4.2	# MIT OR Apache-2.0
MODCARGO_CRATES +=	enum-map-derive	0.11.0	# MIT OR Apache-2.0
MODCARGO_CRATES +=	enum_dispatch	0.3.11	# MIT OR Apache-2.0
MODCARGO_CRATES +=	enumset	1.0.12	# MIT/Apache-2.0
MODCARGO_CRATES +=	enumset_derive	0.6.1	# MIT/Apache-2.0
MODCARGO_CRATES +=	errno	0.2.8	# MIT/Apache-2.0
MODCARGO_CRATES +=	errno-dragonfly	0.1.2	# MIT
MODCARGO_CRATES +=	fastrand	1.9.0	# Apache-2.0 OR MIT
MODCARGO_CRATES +=	fern	0.6.1	# MIT
MODCARGO_CRATES +=	fixedbitset	0.4.2	# MIT/Apache-2.0
MODCARGO_CRATES +=	fnv	1.0.7	# Apache-2.0 / MIT
MODCARGO_CRATES +=	foreign-types	0.3.2	# MIT/Apache-2.0
MODCARGO_CRATES +=	foreign-types-shared	0.1.1	# MIT/Apache-2.0
MODCARGO_CRATES +=	form_urlencoded	1.1.0	# MIT OR Apache-2.0
MODCARGO_CRATES +=	futures	0.3.26	# MIT OR Apache-2.0
MODCARGO_CRATES +=	futures-channel	0.3.26	# MIT OR Apache-2.0
MODCARGO_CRATES +=	futures-core	0.3.26	# MIT OR Apache-2.0
MODCARGO_CRATES +=	futures-executor	0.3.26	# MIT OR Apache-2.0
MODCARGO_CRATES +=	futures-io	0.3.26	# MIT OR Apache-2.0
MODCARGO_CRATES +=	futures-macro	0.3.26	# MIT OR Apache-2.0
MODCARGO_CRATES +=	futures-sink	0.3.26	# MIT OR Apache-2.0
MODCARGO_CRATES +=	futures-task	0.3.26	# MIT OR Apache-2.0
MODCARGO_CRATES +=	futures-util	0.3.26	# MIT OR Apache-2.0
MODCARGO_CRATES +=	generic-array	0.14.6	# MIT
MODCARGO_CRATES +=	getrandom	0.2.8	# MIT OR Apache-2.0
MODCARGO_CRATES +=	gimli	0.27.2	# MIT OR Apache-2.0
MODCARGO_CRATES +=	glob	0.3.1	# MIT OR Apache-2.0
MODCARGO_CRATES +=	h2	0.3.16	# MIT
MODCARGO_CRATES +=	half	1.8.2	# MIT OR Apache-2.0
MODCARGO_CRATES +=	hashbrown	0.12.3	# MIT OR Apache-2.0
MODCARGO_CRATES +=	headers	0.3.8	# MIT
MODCARGO_CRATES +=	headers-core	0.2.0	# MIT
MODCARGO_CRATES +=	heck	0.3.3	# MIT OR Apache-2.0
MODCARGO_CRATES +=	heck	0.4.1	# MIT OR Apache-2.0
MODCARGO_CRATES +=	hermit-abi	0.2.6	# MIT/Apache-2.0
MODCARGO_CRATES +=	hermit-abi	0.3.1	# MIT OR Apache-2.0
MODCARGO_CRATES +=	hmac	0.11.0	# MIT OR Apache-2.0
MODCARGO_CRATES +=	http	0.2.9	# MIT OR Apache-2.0
MODCARGO_CRATES +=	http-body	0.4.5	# MIT
MODCARGO_CRATES +=	httparse	1.8.0	# MIT/Apache-2.0
MODCARGO_CRATES +=	httpdate	1.0.2	# MIT/Apache-2.0
MODCARGO_CRATES +=	hyper	0.14.24	# MIT
MODCARGO_CRATES +=	hyper-proxy	0.9.1	# MIT
MODCARGO_CRATES +=	hyper-tls	0.5.0	# MIT/Apache-2.0
MODCARGO_CRATES +=	iana-time-zone	0.1.53	# MIT OR Apache-2.0
MODCARGO_CRATES +=	iana-time-zone-haiku	0.1.1	# MIT OR Apache-2.0
MODCARGO_CRATES +=	ident_case	1.0.1	# MIT/Apache-2.0
MODCARGO_CRATES +=	idna	0.3.0	# MIT OR Apache-2.0
MODCARGO_CRATES +=	indexmap	1.9.2	# Apache-2.0 OR MIT
MODCARGO_CRATES +=	instant	0.1.12	# BSD-3-Clause
MODCARGO_CRATES +=	io-lifetimes	1.0.6	# Apache-2.0 WITH LLVM-exception OR Apache-2.0 OR MIT
MODCARGO_CRATES +=	ioctl-rs	0.2.0	# MIT
MODCARGO_CRATES +=	ipnet	2.7.1	# MIT OR Apache-2.0
MODCARGO_CRATES +=	is-terminal	0.4.4	# MIT
MODCARGO_CRATES +=	itoa	1.0.6	# MIT OR Apache-2.0
MODCARGO_CRATES +=	jni	0.19.0	# MIT/Apache-2.0
MODCARGO_CRATES +=	jni-sys	0.3.0	# MIT/Apache-2.0
MODCARGO_CRATES +=	jobserver	0.1.26	# MIT/Apache-2.0
MODCARGO_CRATES +=	js-sys	0.3.61	# MIT/Apache-2.0
MODCARGO_CRATES +=	lazy_static	1.4.0	# MIT/Apache-2.0
MODCARGO_CRATES +=	lazycell	1.3.0	# MIT/Apache-2.0
MODCARGO_CRATES +=	lewton	0.10.2	# MIT OR Apache-2.0
MODCARGO_CRATES +=	libc	0.2.140	# MIT OR Apache-2.0
MODCARGO_CRATES +=	libdbus-sys	0.2.4	# Apache-2.0/MIT
MODCARGO_CRATES +=	libloading	0.7.4	# ISC
MODCARGO_CRATES +=	libm	0.2.6	# MIT OR Apache-2.0
MODCARGO_CRATES +=	libpulse-binding	2.27.1	# MIT OR Apache-2.0
MODCARGO_CRATES +=	libpulse-simple-binding	2.27.1	# MIT OR Apache-2.0
MODCARGO_CRATES +=	libpulse-simple-sys	1.20.1	# MIT OR Apache-2.0
MODCARGO_CRATES +=	libpulse-sys	1.20.1	# MIT OR Apache-2.0
MODCARGO_CRATES +=	librespot-audio	0.4.2	# MIT
MODCARGO_CRATES +=	librespot-core	0.4.2	# MIT
MODCARGO_CRATES +=	librespot-metadata	0.4.2	# MIT
MODCARGO_CRATES +=	librespot-playback	0.4.2	# MIT
MODCARGO_CRATES +=	librespot-protocol	0.4.2	# MIT
MODCARGO_CRATES +=	link-cplusplus	1.0.8	# MIT OR Apache-2.0
MODCARGO_CRATES +=	linux-raw-sys	0.1.4	# Apache-2.0 WITH LLVM-exception OR Apache-2.0 OR MIT
MODCARGO_CRATES +=	lock_api	0.4.9	# MIT OR Apache-2.0
MODCARGO_CRATES +=	log	0.4.17	# MIT OR Apache-2.0
MODCARGO_CRATES +=	mac-notification-sys	0.5.6	# MIT
MODCARGO_CRATES +=	mach	0.3.2	# BSD-2-Clause
MODCARGO_CRATES +=	malloc_buf	0.0.6	# MIT
MODCARGO_CRATES +=	maplit	1.0.2	# MIT/Apache-2.0
MODCARGO_CRATES +=	maybe-async	0.2.7	# MIT
MODCARGO_CRATES +=	memchr	2.5.0	# Unlicense/MIT
MODCARGO_CRATES +=	memoffset	0.6.5	# MIT
MODCARGO_CRATES +=	mime	0.3.16	# MIT/Apache-2.0
MODCARGO_CRATES +=	minimal-lexical	0.2.1	# MIT/Apache-2.0
MODCARGO_CRATES +=	miniz_oxide	0.6.2	# MIT OR Zlib OR Apache-2.0
MODCARGO_CRATES +=	mio	0.8.6	# MIT
MODCARGO_CRATES +=	native-tls	0.2.11	# MIT/Apache-2.0
MODCARGO_CRATES +=	ncurses	5.101.0	# MIT
MODCARGO_CRATES +=	ndk	0.6.0	# MIT OR Apache-2.0
MODCARGO_CRATES +=	ndk-context	0.1.1	# MIT OR Apache-2.0
MODCARGO_CRATES +=	ndk-glue	0.6.2	# MIT OR Apache-2.0
MODCARGO_CRATES +=	ndk-macro	0.3.0	# MIT OR Apache-2.0
MODCARGO_CRATES +=	ndk-sys	0.3.0	# MIT OR Apache-2.0
MODCARGO_CRATES +=	nix	0.23.2	# MIT
MODCARGO_CRATES +=	nix	0.24.3	# MIT
MODCARGO_CRATES +=	nom	7.1.3	# MIT
MODCARGO_CRATES +=	notify-rust	4.8.0	# MIT/Apache-2.0
MODCARGO_CRATES +=	num	0.2.1	# MIT/Apache-2.0
MODCARGO_CRATES +=	num	0.4.0	# MIT OR Apache-2.0
MODCARGO_CRATES +=	num-bigint	0.2.6	# MIT/Apache-2.0
MODCARGO_CRATES +=	num-bigint	0.4.3	# MIT OR Apache-2.0
MODCARGO_CRATES +=	num-complex	0.2.4	# MIT/Apache-2.0
MODCARGO_CRATES +=	num-complex	0.4.3	# MIT OR Apache-2.0
MODCARGO_CRATES +=	num-derive	0.3.3	# MIT OR Apache-2.0
MODCARGO_CRATES +=	num-integer	0.1.45	# MIT OR Apache-2.0
MODCARGO_CRATES +=	num-iter	0.1.43	# MIT OR Apache-2.0
MODCARGO_CRATES +=	num-rational	0.2.4	# MIT/Apache-2.0
MODCARGO_CRATES +=	num-rational	0.4.1	# MIT OR Apache-2.0
MODCARGO_CRATES +=	num-traits	0.2.15	# MIT OR Apache-2.0
MODCARGO_CRATES +=	num_cpus	1.15.0	# MIT OR Apache-2.0
MODCARGO_CRATES +=	num_enum	0.5.11	# BSD-3-Clause OR MIT OR Apache-2.0
MODCARGO_CRATES +=	num_enum_derive	0.5.11	# BSD-3-Clause OR MIT OR Apache-2.0
MODCARGO_CRATES +=	num_threads	0.1.6	# MIT OR Apache-2.0
MODCARGO_CRATES +=	numtoa	0.1.0	# MIT OR Apache-2.0
MODCARGO_CRATES +=	objc	0.2.7	# MIT
MODCARGO_CRATES +=	objc-foundation	0.1.1	# MIT
MODCARGO_CRATES +=	objc_id	0.1.1	# MIT
MODCARGO_CRATES +=	object	0.30.3	# Apache-2.0 OR MIT
MODCARGO_CRATES +=	oboe	0.4.6	# Apache-2.0
MODCARGO_CRATES +=	oboe-sys	0.4.5	# Apache-2.0
MODCARGO_CRATES +=	ogg	0.8.0	# BSD-3-Clause
MODCARGO_CRATES +=	once_cell	1.17.1	# MIT OR Apache-2.0
MODCARGO_CRATES +=	opaque-debug	0.3.0	# MIT OR Apache-2.0
MODCARGO_CRATES +=	openssl	0.10.45	# Apache-2.0
MODCARGO_CRATES +=	openssl-macros	0.1.0	# MIT/Apache-2.0
MODCARGO_CRATES +=	openssl-probe	0.1.5	# MIT/Apache-2.0
MODCARGO_CRATES +=	openssl-sys	0.9.80	# MIT
MODCARGO_CRATES +=	os_pipe	1.1.3	# MIT
MODCARGO_CRATES +=	os_str_bytes	6.4.1	# MIT OR Apache-2.0
MODCARGO_CRATES +=	owning_ref	0.4.1	# MIT
MODCARGO_CRATES +=	pancurses	0.17.0	# MIT
MODCARGO_CRATES +=	parking_lot	0.11.2	# Apache-2.0/MIT
MODCARGO_CRATES +=	parking_lot	0.12.1	# MIT OR Apache-2.0
MODCARGO_CRATES +=	parking_lot_core	0.8.6	# Apache-2.0/MIT
MODCARGO_CRATES +=	parking_lot_core	0.9.7	# MIT OR Apache-2.0
MODCARGO_CRATES +=	parse_duration	2.1.1	# MIT
MODCARGO_CRATES +=	pbkdf2	0.8.0	# MIT OR Apache-2.0
MODCARGO_CRATES +=	pdcurses-sys	0.7.1	# MIT
MODCARGO_CRATES +=	peeking_take_while	0.1.2	# Apache-2.0/MIT
MODCARGO_CRATES +=	percent-encoding	2.2.0	# MIT OR Apache-2.0
MODCARGO_CRATES +=	petgraph	0.6.3	# MIT OR Apache-2.0
MODCARGO_CRATES +=	pin-project-lite	0.2.9	# Apache-2.0 OR MIT
MODCARGO_CRATES +=	pin-utils	0.1.0	# MIT OR Apache-2.0
MODCARGO_CRATES +=	pkg-config	0.3.26	# MIT OR Apache-2.0
MODCARGO_CRATES +=	platform-dirs	0.3.0	# MIT
MODCARGO_CRATES +=	portaudio-rs	0.3.2	# MIT
MODCARGO_CRATES +=	portaudio-sys	0.1.1	# MIT
MODCARGO_CRATES +=	ppv-lite86	0.2.17	# MIT/Apache-2.0
MODCARGO_CRATES +=	priority-queue	1.3.1	# LGPL-3.0 OR MPL-2.0
MODCARGO_CRATES +=	proc-macro-crate	1.3.1	# MIT OR Apache-2.0
MODCARGO_CRATES +=	proc-macro2	1.0.51	# MIT OR Apache-2.0
MODCARGO_CRATES +=	protobuf	2.28.0	# MIT
MODCARGO_CRATES +=	protobuf-codegen	2.28.0	# MIT
MODCARGO_CRATES +=	protobuf-codegen-pure	2.28.0	# MIT
MODCARGO_CRATES +=	quick-xml	0.23.1	# MIT
MODCARGO_CRATES +=	quote	1.0.23	# MIT OR Apache-2.0
MODCARGO_CRATES +=	rand	0.8.5	# MIT OR Apache-2.0
MODCARGO_CRATES +=	rand_chacha	0.3.1	# MIT OR Apache-2.0
MODCARGO_CRATES +=	rand_core	0.6.4	# MIT OR Apache-2.0
MODCARGO_CRATES +=	rand_distr	0.4.3	# MIT OR Apache-2.0
MODCARGO_CRATES +=	redox_syscall	0.2.16	# MIT
MODCARGO_CRATES +=	redox_termios	0.1.2	# MIT
MODCARGO_CRATES +=	redox_users	0.4.3	# MIT
MODCARGO_CRATES +=	regex	1.7.1	# MIT OR Apache-2.0
MODCARGO_CRATES +=	regex-syntax	0.6.28	# MIT OR Apache-2.0
MODCARGO_CRATES +=	reqwest	0.11.14	# MIT OR Apache-2.0
MODCARGO_CRATES +=	ring	0.16.20	# LICENSE
MODCARGO_CRATES +=	rodio	0.15.0	# MIT OR Apache-2.0
MODCARGO_CRATES +=	roff	0.2.1	# MIT OR Apache-2.0
MODCARGO_CRATES +=	rspotify	0.11.6	# MIT
MODCARGO_CRATES +=	rspotify-http	0.11.6	# MIT
MODCARGO_CRATES +=	rspotify-macros	0.11.6	# MIT
MODCARGO_CRATES +=	rspotify-model	0.11.6	# MIT
MODCARGO_CRATES +=	rustc-demangle	0.1.21	# MIT/Apache-2.0
MODCARGO_CRATES +=	rustc-hash	1.1.0	# Apache-2.0/MIT
MODCARGO_CRATES +=	rustc-serialize	0.3.24	# MIT/Apache-2.0
MODCARGO_CRATES +=	rustc_version	0.4.0	# MIT/Apache-2.0
MODCARGO_CRATES +=	rustix	0.36.9	# Apache-2.0 WITH LLVM-exception OR Apache-2.0 OR MIT
MODCARGO_CRATES +=	rustls	0.20.8	# Apache-2.0/ISC/MIT
MODCARGO_CRATES +=	rustversion	1.0.12	# MIT OR Apache-2.0
MODCARGO_CRATES +=	ryu	1.0.13	# Apache-2.0 OR BSL-1.0
MODCARGO_CRATES +=	same-file	1.0.6	# Unlicense/MIT
MODCARGO_CRATES +=	schannel	0.1.21	# MIT
MODCARGO_CRATES +=	scopeguard	1.1.0	# MIT/Apache-2.0
MODCARGO_CRATES +=	scratch	1.0.5	# MIT OR Apache-2.0
MODCARGO_CRATES +=	sct	0.7.0	# Apache-2.0/ISC/MIT
MODCARGO_CRATES +=	security-framework	2.8.2	# MIT OR Apache-2.0
MODCARGO_CRATES +=	security-framework-sys	2.8.0	# MIT OR Apache-2.0
MODCARGO_CRATES +=	semver	1.0.16	# MIT OR Apache-2.0
MODCARGO_CRATES +=	serde	1.0.154	# MIT OR Apache-2.0
MODCARGO_CRATES +=	serde_cbor	0.11.2	# MIT/Apache-2.0
MODCARGO_CRATES +=	serde_derive	1.0.154	# MIT OR Apache-2.0
MODCARGO_CRATES +=	serde_json	1.0.94	# MIT OR Apache-2.0
MODCARGO_CRATES +=	serde_spanned	0.6.1	# MIT OR Apache-2.0
MODCARGO_CRATES +=	serde_urlencoded	0.7.1	# MIT/Apache-2.0
MODCARGO_CRATES +=	sha-1	0.9.8	# MIT OR Apache-2.0
MODCARGO_CRATES +=	sha1	0.10.5	# MIT OR Apache-2.0
MODCARGO_CRATES +=	sha2	0.10.6	# MIT OR Apache-2.0
MODCARGO_CRATES +=	shannon	0.2.0	# MIT
MODCARGO_CRATES +=	shell-words	1.1.0	# MIT/Apache-2.0
MODCARGO_CRATES +=	shlex	1.1.0	# MIT OR Apache-2.0
MODCARGO_CRATES +=	signal-hook	0.3.15	# Apache-2.0/MIT
MODCARGO_CRATES +=	signal-hook-registry	1.4.1	# Apache-2.0/MIT
MODCARGO_CRATES +=	slab	0.4.8	# MIT
MODCARGO_CRATES +=	smallvec	1.10.0	# MIT OR Apache-2.0
MODCARGO_CRATES +=	socket2	0.4.9	# MIT OR Apache-2.0
MODCARGO_CRATES +=	spin	0.5.2	# MIT
MODCARGO_CRATES +=	stable_deref_trait	1.2.0	# MIT/Apache-2.0
MODCARGO_CRATES +=	stdweb	0.1.3	# MIT/Apache-2.0
MODCARGO_CRATES +=	strsim	0.10.0	# MIT
MODCARGO_CRATES +=	strum	0.22.0	# MIT
MODCARGO_CRATES +=	strum	0.24.1	# MIT
MODCARGO_CRATES +=	strum_macros	0.22.0	# MIT
MODCARGO_CRATES +=	strum_macros	0.24.3	# MIT
MODCARGO_CRATES +=	subtle	2.4.1	# BSD-3-Clause
MODCARGO_CRATES +=	syn	1.0.109	# MIT OR Apache-2.0
MODCARGO_CRATES +=	tauri-winrt-notification	0.1.0	# MIT OR Apache-2.0
MODCARGO_CRATES +=	tempfile	3.4.0	# MIT OR Apache-2.0
MODCARGO_CRATES +=	term_size	0.3.2	# MIT/Apache-2.0
MODCARGO_CRATES +=	termcolor	1.2.0	# Unlicense OR MIT
MODCARGO_CRATES +=	termion	1.5.6	# MIT
MODCARGO_CRATES +=	thiserror	1.0.39	# MIT OR Apache-2.0
MODCARGO_CRATES +=	thiserror-impl	1.0.39	# MIT OR Apache-2.0
MODCARGO_CRATES +=	thread-id	4.0.0	# MIT/Apache-2.0
MODCARGO_CRATES +=	time	0.1.45	# MIT/Apache-2.0
MODCARGO_CRATES +=	time	0.3.20	# MIT OR Apache-2.0
MODCARGO_CRATES +=	time-core	0.1.0	# MIT OR Apache-2.0
MODCARGO_CRATES +=	time-macros	0.2.8	# MIT OR Apache-2.0
MODCARGO_CRATES +=	tinyvec	1.6.0	# Zlib OR Apache-2.0 OR MIT
MODCARGO_CRATES +=	tinyvec_macros	0.1.1	# MIT OR Apache-2.0 OR Zlib
MODCARGO_CRATES +=	tokio	1.26.0	# MIT
MODCARGO_CRATES +=	tokio-macros	1.8.2	# MIT
MODCARGO_CRATES +=	tokio-native-tls	0.3.1	# MIT
MODCARGO_CRATES +=	tokio-stream	0.1.12	# MIT
MODCARGO_CRATES +=	tokio-util	0.7.7	# MIT
MODCARGO_CRATES +=	toml	0.7.2	# MIT OR Apache-2.0
MODCARGO_CRATES +=	toml_datetime	0.6.1	# MIT OR Apache-2.0
MODCARGO_CRATES +=	toml_edit	0.19.4	# MIT OR Apache-2.0
MODCARGO_CRATES +=	tower-service	0.3.2	# MIT
MODCARGO_CRATES +=	tracing	0.1.37	# MIT
MODCARGO_CRATES +=	tracing-core	0.1.30	# MIT
MODCARGO_CRATES +=	tree_magic_mini	3.0.3	# MIT
MODCARGO_CRATES +=	try-lock	0.2.4	# MIT
MODCARGO_CRATES +=	typenum	1.16.0	# MIT OR Apache-2.0
MODCARGO_CRATES +=	unicode-bidi	0.3.11	# MIT OR Apache-2.0
MODCARGO_CRATES +=	unicode-ident	1.0.8	# (MIT OR Apache-2.0) AND Unicode-DFS-2016
MODCARGO_CRATES +=	unicode-normalization	0.1.22	# MIT/Apache-2.0
MODCARGO_CRATES +=	unicode-segmentation	1.10.1	# MIT/Apache-2.0
MODCARGO_CRATES +=	unicode-width	0.1.10	# MIT/Apache-2.0
MODCARGO_CRATES +=	untrusted	0.7.1	# ISC
MODCARGO_CRATES +=	ureq	2.6.2	# MIT/Apache-2.0
MODCARGO_CRATES +=	url	2.3.1	# MIT OR Apache-2.0
MODCARGO_CRATES +=	uuid	1.3.0	# Apache-2.0 OR MIT
MODCARGO_CRATES +=	vcpkg	0.2.15	# MIT/Apache-2.0
MODCARGO_CRATES +=	vergen	3.2.0	# MIT/Apache-2.0
MODCARGO_CRATES +=	version_check	0.9.4	# MIT/Apache-2.0
MODCARGO_CRATES +=	walkdir	2.3.2	# Unlicense/MIT
MODCARGO_CRATES +=	want	0.3.0	# MIT
MODCARGO_CRATES +=	wasi	0.10.0+wasi-snapshot-preview1	# Apache-2.0 WITH LLVM-exception OR Apache-2.0 OR MIT
MODCARGO_CRATES +=	wasi	0.11.0+wasi-snapshot-preview1	# Apache-2.0 WITH LLVM-exception OR Apache-2.0 OR MIT
MODCARGO_CRATES +=	wasm-bindgen	0.2.84	# MIT/Apache-2.0
MODCARGO_CRATES +=	wasm-bindgen-backend	0.2.84	# MIT/Apache-2.0
MODCARGO_CRATES +=	wasm-bindgen-futures	0.4.34	# MIT/Apache-2.0
MODCARGO_CRATES +=	wasm-bindgen-macro	0.2.84	# MIT/Apache-2.0
MODCARGO_CRATES +=	wasm-bindgen-macro-support	0.2.84	# MIT/Apache-2.0
MODCARGO_CRATES +=	wasm-bindgen-shared	0.2.84	# MIT/Apache-2.0
MODCARGO_CRATES +=	wayland-client	0.29.5	# MIT
MODCARGO_CRATES +=	wayland-commons	0.29.5	# MIT
MODCARGO_CRATES +=	wayland-protocols	0.29.5	# MIT
MODCARGO_CRATES +=	wayland-scanner	0.29.5	# MIT
MODCARGO_CRATES +=	wayland-sys	0.29.5	# MIT
MODCARGO_CRATES +=	web-sys	0.3.61	# MIT/Apache-2.0
MODCARGO_CRATES +=	webpki	0.22.0	# LICENSE
MODCARGO_CRATES +=	webpki-roots	0.22.6	# MPL-2.0
MODCARGO_CRATES +=	winapi	0.3.9	# MIT/Apache-2.0
MODCARGO_CRATES +=	winapi-i686-pc-windows-gnu	0.4.0	# MIT/Apache-2.0
MODCARGO_CRATES +=	winapi-util	0.1.5	# Unlicense/MIT
MODCARGO_CRATES +=	winapi-x86_64-pc-windows-gnu	0.4.0	# MIT/Apache-2.0
MODCARGO_CRATES +=	windows	0.39.0	# MIT OR Apache-2.0
MODCARGO_CRATES +=	windows-sys	0.42.0	# MIT OR Apache-2.0
MODCARGO_CRATES +=	windows-sys	0.45.0	# MIT OR Apache-2.0
MODCARGO_CRATES +=	windows-targets	0.42.1	# MIT OR Apache-2.0
MODCARGO_CRATES +=	windows_aarch64_gnullvm	0.42.1	# MIT OR Apache-2.0
MODCARGO_CRATES +=	windows_aarch64_msvc	0.39.0	# MIT OR Apache-2.0
MODCARGO_CRATES +=	windows_aarch64_msvc	0.42.1	# MIT OR Apache-2.0
MODCARGO_CRATES +=	windows_i686_gnu	0.39.0	# MIT OR Apache-2.0
MODCARGO_CRATES +=	windows_i686_gnu	0.42.1	# MIT OR Apache-2.0
MODCARGO_CRATES +=	windows_i686_msvc	0.39.0	# MIT OR Apache-2.0
MODCARGO_CRATES +=	windows_i686_msvc	0.42.1	# MIT OR Apache-2.0
MODCARGO_CRATES +=	windows_x86_64_gnu	0.39.0	# MIT OR Apache-2.0
MODCARGO_CRATES +=	windows_x86_64_gnu	0.42.1	# MIT OR Apache-2.0
MODCARGO_CRATES +=	windows_x86_64_gnullvm	0.42.1	# MIT OR Apache-2.0
MODCARGO_CRATES +=	windows_x86_64_msvc	0.39.0	# MIT OR Apache-2.0
MODCARGO_CRATES +=	windows_x86_64_msvc	0.42.1	# MIT OR Apache-2.0
MODCARGO_CRATES +=	winnow	0.3.5	# MIT
MODCARGO_CRATES +=	winreg	0.5.1	# MIT
MODCARGO_CRATES +=	winreg	0.10.1	# MIT
MODCARGO_CRATES +=	wl-clipboard-rs	0.7.0	# MIT/Apache-2.0
MODCARGO_CRATES +=	x11-clipboard	0.3.3	# MIT
MODCARGO_CRATES +=	xcb	0.8.2	# MIT
MODCARGO_CRATES +=	xi-unicode	0.3.0	# Apache-2.0
MODCARGO_CRATES +=	xml-rs	0.8.4	# MIT
MODCARGO_CRATES +=	zerocopy	0.6.1	# LICENSE
MODCARGO_CRATES +=	zerocopy-derive	0.3.2	# LICENSE
