MODCARGO_CRATES +=	aho-corasick	0.7.19	# Unlicense/MIT
MODCARGO_CRATES +=	anyhow	1.0.64	# MIT OR Apache-2.0
MODCARGO_CRATES +=	approx	0.5.1	# Apache-2.0
MODCARGO_CRATES +=	arrayvec	0.7.2	# MIT OR Apache-2.0
MODCARGO_CRATES +=	assert_cmd	2.0.4	# MIT OR Apache-2.0
MODCARGO_CRATES +=	atty	0.2.14	# MIT
MODCARGO_CRATES +=	autocfg	0.1.8	# Apache-2.0 OR MIT
MODCARGO_CRATES +=	autocfg	1.1.0	# Apache-2.0 OR MIT
MODCARGO_CRATES +=	bitflags	1.3.2	# MIT/Apache-2.0
MODCARGO_CRATES +=	bstr	0.2.17	# MIT OR Apache-2.0
MODCARGO_CRATES +=	cfg-if	1.0.0	# MIT/Apache-2.0
MODCARGO_CRATES +=	clap	3.2.20	# MIT OR Apache-2.0
MODCARGO_CRATES +=	clap_complete	3.2.4	# MIT OR Apache-2.0
MODCARGO_CRATES +=	clap_lex	0.2.4	# MIT OR Apache-2.0
MODCARGO_CRATES +=	cloudabi	0.0.3	# BSD-2-Clause
MODCARGO_CRATES +=	colored	2.0.0	# MPL-2.0
MODCARGO_CRATES +=	console	0.15.1	# MIT
MODCARGO_CRATES +=	csv	1.1.6	# Unlicense/MIT
MODCARGO_CRATES +=	csv-core	0.1.10	# Unlicense/MIT
MODCARGO_CRATES +=	difflib	0.4.0	# MIT
MODCARGO_CRATES +=	doc-comment	0.3.3	# MIT
MODCARGO_CRATES +=	either	1.8.0	# MIT/Apache-2.0
MODCARGO_CRATES +=	encode_unicode	0.3.6	# MIT/Apache-2.0
MODCARGO_CRATES +=	fastrand	1.8.0	# Apache-2.0 OR MIT
MODCARGO_CRATES +=	float-cmp	0.9.0	# MIT
MODCARGO_CRATES +=	fuchsia-cprng	0.1.1	# LICENSE
MODCARGO_CRATES +=	getrandom	0.2.7	# MIT OR Apache-2.0
MODCARGO_CRATES +=	hashbrown	0.12.3	# MIT OR Apache-2.0
MODCARGO_CRATES +=	hermit-abi	0.1.19	# MIT/Apache-2.0
MODCARGO_CRATES +=	indexmap	1.9.1	# Apache-2.0 OR MIT
MODCARGO_CRATES +=	indicatif	0.16.2	# MIT
MODCARGO_CRATES +=	instant	0.1.12	# BSD-3-Clause
MODCARGO_CRATES +=	itertools	0.10.3	# MIT/Apache-2.0
MODCARGO_CRATES +=	itoa	0.4.8	# MIT OR Apache-2.0
MODCARGO_CRATES +=	itoa	1.0.3	# MIT OR Apache-2.0
MODCARGO_CRATES +=	lazy_static	1.4.0	# MIT/Apache-2.0
MODCARGO_CRATES +=	libc	0.2.132	# MIT OR Apache-2.0
MODCARGO_CRATES +=	memchr	2.5.0	# Unlicense/MIT
MODCARGO_CRATES +=	memoffset	0.6.5	# MIT
MODCARGO_CRATES +=	nix	0.25.0	# MIT
MODCARGO_CRATES +=	normalize-line-endings	0.3.0	# Apache-2.0
MODCARGO_CRATES +=	num	0.2.1	# MIT/Apache-2.0
MODCARGO_CRATES +=	num-bigint	0.2.6	# MIT/Apache-2.0
MODCARGO_CRATES +=	num-complex	0.2.4	# MIT/Apache-2.0
MODCARGO_CRATES +=	num-integer	0.1.45	# MIT OR Apache-2.0
MODCARGO_CRATES +=	num-iter	0.1.43	# MIT OR Apache-2.0
MODCARGO_CRATES +=	num-rational	0.2.4	# MIT/Apache-2.0
MODCARGO_CRATES +=	num-traits	0.2.15	# MIT OR Apache-2.0
MODCARGO_CRATES +=	number_prefix	0.4.0	# MIT
MODCARGO_CRATES +=	once_cell	1.14.0	# MIT OR Apache-2.0
MODCARGO_CRATES +=	os_str_bytes	6.3.0	# MIT OR Apache-2.0
MODCARGO_CRATES +=	pin-utils	0.1.0	# MIT OR Apache-2.0
MODCARGO_CRATES +=	ppv-lite86	0.2.16	# MIT/Apache-2.0
MODCARGO_CRATES +=	predicates	2.1.1	# MIT OR Apache-2.0
MODCARGO_CRATES +=	predicates-core	1.0.3	# MIT OR Apache-2.0
MODCARGO_CRATES +=	predicates-tree	1.0.5	# MIT OR Apache-2.0
MODCARGO_CRATES +=	proc-macro2	1.0.43	# MIT OR Apache-2.0
MODCARGO_CRATES +=	quote	1.0.21	# MIT OR Apache-2.0
MODCARGO_CRATES +=	rand	0.6.5	# MIT/Apache-2.0
MODCARGO_CRATES +=	rand	0.8.5	# MIT OR Apache-2.0
MODCARGO_CRATES +=	rand_chacha	0.1.1	# MIT/Apache-2.0
MODCARGO_CRATES +=	rand_chacha	0.3.1	# MIT OR Apache-2.0
MODCARGO_CRATES +=	rand_core	0.3.1	# MIT/Apache-2.0
MODCARGO_CRATES +=	rand_core	0.4.2	# MIT/Apache-2.0
MODCARGO_CRATES +=	rand_core	0.6.3	# MIT OR Apache-2.0
MODCARGO_CRATES +=	rand_hc	0.1.0	# MIT/Apache-2.0
MODCARGO_CRATES +=	rand_isaac	0.1.1	# MIT/Apache-2.0
MODCARGO_CRATES +=	rand_jitter	0.1.4	# MIT OR Apache-2.0
MODCARGO_CRATES +=	rand_os	0.1.3	# MIT/Apache-2.0
MODCARGO_CRATES +=	rand_pcg	0.1.2	# MIT/Apache-2.0
MODCARGO_CRATES +=	rand_xorshift	0.1.1	# MIT/Apache-2.0
MODCARGO_CRATES +=	rdrand	0.4.0	# ISC
MODCARGO_CRATES +=	redox_syscall	0.2.16	# MIT
MODCARGO_CRATES +=	regex	1.6.0	# MIT OR Apache-2.0
MODCARGO_CRATES +=	regex-automata	0.1.10	# Unlicense/MIT
MODCARGO_CRATES +=	regex-syntax	0.6.27	# MIT OR Apache-2.0
MODCARGO_CRATES +=	remove_dir_all	0.5.3	# MIT/Apache-2.0
MODCARGO_CRATES +=	rust_decimal	1.26.1	# MIT
MODCARGO_CRATES +=	ryu	1.0.11	# Apache-2.0 OR BSL-1.0
MODCARGO_CRATES +=	serde	1.0.144	# MIT OR Apache-2.0
MODCARGO_CRATES +=	serde_derive	1.0.144	# MIT OR Apache-2.0
MODCARGO_CRATES +=	serde_json	1.0.85	# MIT OR Apache-2.0
MODCARGO_CRATES +=	shell-words	1.1.0	# MIT/Apache-2.0
MODCARGO_CRATES +=	statistical	1.0.0	# MIT
MODCARGO_CRATES +=	strsim	0.10.0	# MIT
MODCARGO_CRATES +=	syn	1.0.99	# MIT OR Apache-2.0
MODCARGO_CRATES +=	tempfile	3.3.0	# MIT OR Apache-2.0
MODCARGO_CRATES +=	termcolor	1.1.3	# Unlicense OR MIT
MODCARGO_CRATES +=	terminal_size	0.1.17	# MIT OR Apache-2.0
MODCARGO_CRATES +=	termtree	0.2.4	# MIT
MODCARGO_CRATES +=	textwrap	0.15.0	# MIT
MODCARGO_CRATES +=	thiserror	1.0.34	# MIT OR Apache-2.0
MODCARGO_CRATES +=	thiserror-impl	1.0.34	# MIT OR Apache-2.0
MODCARGO_CRATES +=	unicode-ident	1.0.3	# (MIT OR Apache-2.0) AND Unicode-DFS-2016
MODCARGO_CRATES +=	wait-timeout	0.2.0	# MIT/Apache-2.0
MODCARGO_CRATES +=	wasi	0.11.0+wasi-snapshot-preview1	# Apache-2.0 WITH LLVM-exception OR Apache-2.0 OR MIT
MODCARGO_CRATES +=	winapi	0.3.9	# MIT/Apache-2.0
MODCARGO_CRATES +=	winapi-i686-pc-windows-gnu	0.4.0	# MIT/Apache-2.0
MODCARGO_CRATES +=	winapi-util	0.1.5	# Unlicense/MIT
MODCARGO_CRATES +=	winapi-x86_64-pc-windows-gnu	0.4.0	# MIT/Apache-2.0
