MODGO_MODULES =	\
	4d63.com/gochecknoglobals				 v0.1.0 \
	cloud.google.com/go					 v0.100.2 \
	cloud.google.com/go/bigquery				 v1.8.0 \
	cloud.google.com/go/compute				 v1.6.1 \
	cloud.google.com/go/datastore				 v1.1.0 \
	cloud.google.com/go/firestore				 v1.6.1 \
	cloud.google.com/go/pubsub				 v1.3.1 \
	cloud.google.com/go/storage				 v1.14.0 \
	code.cloudfoundry.org/go-diodes				 v0.0.0-20190809170250-f77fb823c7ee \
	dmitri.shuralyov.com/gpu/mtl				 v0.0.0-20190408044501-666a987793e9 \
	github.com/!antonboom/errname				 v0.1.7 \
	github.com/!antonboom/nilnil				 v0.1.1 \
	github.com/!burnt!sushi/toml				 v1.2.0 \
	github.com/!burnt!sushi/xgb				 v0.0.0-20160522181843-27f122750802 \
	github.com/!click!house/clickhouse-go			 v1.4.5 \
	github.com/!djarvur/go-err113				 v0.0.0-20210108212216-aea10b59be24 \
	github.com/!gaijin!entertainment/go-exhaustruct/v2	 v2.3.0 \
	github.com/!knetic/govaluate				 v3.0.1-0.20171022003610-9aa49832a739+incompatible \
	github.com/!masterminds/semver				 v1.5.0 \
	github.com/!masterminds/squirrel			 v1.5.3 \
	github.com/!open!pee!dee!p/depguard			 v1.1.0 \
	github.com/!rene!kroon/ttlcache/v2			 v2.11.0 \
	github.com/alecthomas/template				 v0.0.0-20190718012654-fb15b899a751 \
	github.com/alecthomas/units				 v0.0.0-20190924025748-f65c72e2690d \
	github.com/alexkohler/prealloc				 v1.0.0 \
	github.com/alingse/asasalint				 v0.0.11 \
	github.com/armon/go-metrics				 v0.3.10 \
	github.com/ashanbrown/forbidigo				 v1.3.0 \
	github.com/ashanbrown/makezero				 v1.1.1 \
	github.com/aymerick/douceur				 v0.2.0 \
	github.com/beego/beego/v2				 v2.0.5 \
	github.com/beego/x2j					 v0.0.0-20131220205130-a0352aadc542 \
	github.com/beorn7/perks					 v1.0.1 \
	github.com/bkaradzic/go-lz4				 v1.0.0 \
	github.com/bkielbasa/cyclop				 v1.2.0 \
	github.com/blizzy78/varnamelen				 v0.8.0 \
	github.com/bombsimon/wsl/v3				 v3.3.0 \
	github.com/bradfitz/gomemcache				 v0.0.0-20190913173617-a41fca850d0b \
	github.com/bradleyjkemp/cupaloy				 v2.3.0+incompatible \
	github.com/breml/bidichk				 v0.2.3 \
	github.com/breml/errchkjson				 v0.3.0 \
	github.com/butuzov/ireturn				 v0.1.1 \
	github.com/casbin/casbin				 v1.9.1 \
	github.com/census-instrumentation/opencensus-proto	 v0.2.1 \
	github.com/cespare/reflex				 v0.3.1 \
	github.com/cespare/xxhash/v2				 v2.1.2 \
	github.com/charithe/durationcheck			 v0.0.9 \
	github.com/chavacava/garif				 v0.0.0-20220630083739-93517212f375 \
	github.com/chzyer/logex					 v1.1.10 \
	github.com/chzyer/readline				 v1.5.0 \
	github.com/chzyer/test					 v0.0.0-20180213035817-a1ea475d72b1 \
	github.com/client9/misspell				 v0.3.4 \
	github.com/cloudflare/golz4				 v0.0.0-20150217214814-ef862a3cdc58 \
	github.com/cncf/udpa/go					 v0.0.0-20201120205902-5459f2c99403 \
	github.com/coreos/go-semver				 v0.3.0 \
	github.com/coreos/go-systemd/v22			 v22.3.2 \
	github.com/couchbase/go-couchbase			 v0.1.0 \
	github.com/couchbase/gomemcached			 v0.1.3 \
	github.com/couchbase/goutils				 v0.1.0 \
	github.com/cpuguy83/go-md2man/v2			 v2.0.2 \
	github.com/creack/pty					 v1.1.11 \
	github.com/cristalhq/acmd				 v0.7.0 \
	github.com/cupcake/rdb					 v0.0.0-20161107195141-43ba34106c76 \
	github.com/curioswitch/go-reassign			 v0.1.2 \
	github.com/daixiang0/gci				 v0.6.3 \
	github.com/davecgh/go-spew				 v1.1.1 \
	github.com/decred/dcrd/crypto/blake256			 v1.0.0 \
	github.com/decred/dcrd/dcrec/secp256k1/v4		 v4.0.0-20210816181553-5444fa50b93d \
	github.com/deluan/rest					 v0.0.0-20211101235434-380523c4bb47 \
	github.com/denis-tingaikin/go-header			 v0.4.3 \
	github.com/denisenkom/go-mssqldb			 v0.10.0 \
	github.com/dhowden/itl					 v0.0.0-20170329215456-9fbe21093131 \
	github.com/dhowden/plist				 v0.0.0-20141002110153-5db6e0d9931a \
	github.com/dhowden/tag					 v0.0.0-20220618230019-adf36e896086 \
	github.com/disintegration/imaging			 v1.6.2 \
	github.com/djherbis/atime				 v1.1.0 \
	github.com/djherbis/fscache				 v0.10.2-0.20220222230828-2909c950912d \
	github.com/djherbis/stream				 v1.4.0 \
	github.com/dustin/go-humanize				 v1.0.0 \
	github.com/edsrzf/mmap-go				 v1.0.0 \
	github.com/elastic/go-elasticsearch/v6			 v6.8.10 \
	github.com/elazarl/go-bindata-assetfs			 v1.0.1 \
	github.com/envoyproxy/go-control-plane			 v0.9.9-0.20201210154907-fd9021fe5dad \
	github.com/envoyproxy/protoc-gen-validate		 v0.1.0 \
	github.com/esimonov/ifshort				 v1.0.4 \
	github.com/ettle/strcase				 v0.1.1 \
	github.com/fatih/color					 v1.13.0 \
	github.com/fatih/structs				 v1.1.0 \
	github.com/fatih/structtag				 v1.2.0 \
	github.com/firefart/nonamedreturns			 v1.0.4 \
	github.com/frankban/quicktest				 v1.14.3 \
	github.com/fsnotify/fsnotify				 v1.5.4 \
	github.com/fzipp/gocyclo				 v0.6.0 \
	github.com/go-chi/chi/v5				 v5.0.7 \
	github.com/go-chi/cors					 v1.2.1 \
	github.com/go-chi/httprate				 v0.7.0 \
	github.com/go-chi/jwtauth/v5				 v5.0.2 \
	github.com/go-critic/go-critic				 v0.6.4 \
	github.com/go-gl/glfw					 v0.0.0-20190409004039-e6da0acd62b1 \
	github.com/go-gl/glfw/v3.3/glfw				 v0.0.0-20200222043503-6f7a984d4dc4 \
	github.com/go-kit/kit					 v0.10.0 \
	github.com/go-kit/log					 v0.2.0 \
	github.com/go-logfmt/logfmt				 v0.5.1 \
	github.com/go-logr/logr					 v1.2.3 \
	github.com/go-logr/stdr					 v1.2.2 \
	github.com/go-ole/go-ole				 v1.2.6 \
	github.com/go-redis/redis/v7				 v7.4.0 \
	github.com/go-sql-driver/mysql				 v1.6.0 \
	github.com/go-stack/stack				 v1.8.0 \
	github.com/go-task/slim-sprig				 v0.0.0-20210107165309-348f09dbbbc0 \
	github.com/go-toolsmith/astcast				 v1.0.0 \
	github.com/go-toolsmith/astcopy				 v1.0.1 \
	github.com/go-toolsmith/astequal			 v1.0.2 \
	github.com/go-toolsmith/astfmt				 v1.0.0 \
	github.com/go-toolsmith/astp				 v1.0.0 \
	github.com/go-toolsmith/pkgload				 v1.0.2-0.20220101231613-e814995d17c5 \
	github.com/go-toolsmith/strparse			 v1.0.0 \
	github.com/go-toolsmith/typep				 v1.0.2 \
	github.com/go-xmlfmt/xmlfmt				 v0.0.0-20191208150333-d5b6f63a941b \
	github.com/gobwas/glob					 v0.2.3 \
	github.com/goccy/go-json				 v0.9.7 \
	github.com/gofrs/flock					 v0.8.1 \
	github.com/gogo/protobuf				 v1.3.2 \
	github.com/golang-sql/civil				 v0.0.0-20190719163853-cb61b32ac6fe \
	github.com/golang/glog					 v0.0.0-20160126235308-23def4e6c14b \
	github.com/golang/groupcache				 v0.0.0-20210331224755-41bb18bfe9da \
	github.com/golang/mock					 v1.4.4 \
	github.com/golang/protobuf				 v1.5.2 \
	github.com/golang/snappy				 v0.0.0-20180518054509-2e65f85255db \
	github.com/golangci/check				 v0.0.0-20180506172741-cfe4005ccda2 \
	github.com/golangci/dupl				 v0.0.0-20180902072040-3e9179ac440a \
	github.com/golangci/go-misc				 v0.0.0-20220329215616-d24fe342adfe \
	github.com/golangci/gofmt				 v0.0.0-20190930125516-244bba706f1a \
	github.com/golangci/golangci-lint			 v1.49.0 \
	github.com/golangci/lint-1				 v0.0.0-20191013205115-297bf364a8e0 \
	github.com/golangci/maligned				 v0.0.0-20180506175553-b1d89398deca \
	github.com/golangci/misspell				 v0.3.5 \
	github.com/golangci/revgrep				 v0.0.0-20220804021717-745bb2f7c2e6 \
	github.com/golangci/unconvert				 v0.0.0-20180507085042-28b1c447d1f4 \
	github.com/gomodule/redigo				 v2.0.0+incompatible \
	github.com/google/btree					 v1.0.0 \
	github.com/google/go-cmp				 v0.5.8 \
	github.com/google/gofuzz				 v1.0.0 \
	github.com/google/martian				 v2.1.0+incompatible \
	github.com/google/martian/v3				 v3.1.0 \
	github.com/google/pprof					 v0.0.0-20220829040838-70bd9ae97f40 \
	github.com/google/renameio				 v0.1.0 \
	github.com/google/subcommands				 v1.0.1 \
	github.com/google/uuid					 v1.3.0 \
	github.com/google/wire					 v0.5.0 \
	github.com/googleapis/gax-go/v2				 v2.4.0 \
	github.com/googleapis/google-cloud-go-testing		 v0.0.0-20200911160855-bcd43fbb19e8 \
	github.com/gookit/color					 v1.5.1 \
	github.com/gopherjs/gopherjs				 v0.0.0-20181017120253-0766667cb4d1 \
	github.com/gordonklaus/ineffassign			 v0.0.0-20210914165742-4cc7213b9bc8 \
	github.com/gorilla/css					 v1.0.0 \
	github.com/gostaticanalysis/analysisutil		 v0.7.1 \
	github.com/gostaticanalysis/comment			 v1.4.2 \
	github.com/gostaticanalysis/forcetypeassert		 v0.1.0 \
	github.com/gostaticanalysis/nilerr			 v0.1.1 \
	github.com/gostaticanalysis/testutil			 v0.4.0 \
	github.com/grpc-ecosystem/go-grpc-prometheus		 v1.2.0 \
	github.com/hashicorp/consul/api				 v1.12.0 \
	github.com/hashicorp/errwrap				 v1.0.0 \
	github.com/hashicorp/go-cleanhttp			 v0.5.2 \
	github.com/hashicorp/go-hclog				 v1.2.0 \
	github.com/hashicorp/go-immutable-radix			 v1.3.1 \
	github.com/hashicorp/go-multierror			 v1.1.1 \
	github.com/hashicorp/go-rootcerts			 v1.0.2 \
	github.com/hashicorp/go-version				 v1.6.0 \
	github.com/hashicorp/golang-lru				 v0.5.4 \
	github.com/hashicorp/hcl				 v1.0.0 \
	github.com/hashicorp/serf				 v0.9.7 \
	github.com/hexops/gotextdiff				 v1.0.3 \
	github.com/hpcloud/tail					 v1.0.0 \
	github.com/ianlancetaylor/demangle			 v0.0.0-20220319035150-800ac71e25c2 \
	github.com/inconshreveable/mousetrap			 v1.0.0 \
	github.com/jgautheron/goconst				 v1.5.1 \
	github.com/jingyugao/rowserrcheck			 v1.1.1 \
	github.com/jirfag/go-printf-func-name			 v0.0.0-20200119135958-7558a9eaa5af \
	github.com/jmoiron/sqlx					 v1.2.0 \
	github.com/jpillora/backoff				 v1.0.0 \
	github.com/json-iterator/go				 v1.1.12 \
	github.com/jstemmer/go-junit-report			 v0.9.1 \
	github.com/jtolds/gls					 v4.20.0+incompatible \
	github.com/julienschmidt/httprouter			 v1.3.0 \
	github.com/julz/importas				 v0.1.0 \
	github.com/kballard/go-shellquote			 v0.0.0-20180428030007-95032a82bc51 \
	github.com/kennygrant/sanitize				 v0.0.0-20170120101633-6a0bfdde8629 \
	github.com/kisielk/errcheck				 v1.6.2 \
	github.com/kisielk/gotool				 v1.0.0 \
	github.com/konsorten/go-windows-terminal-sequences	 v1.0.3 \
	github.com/kr/fs					 v0.1.0 \
	github.com/kr/logfmt					 v0.0.0-20140226030751-b84e30acd515 \
	github.com/kr/pretty					 v0.3.0 \
	github.com/kr/pty					 v1.1.1 \
	github.com/kr/text					 v0.2.0 \
	github.com/kulti/thelper				 v0.6.3 \
	github.com/kunwardeep/paralleltest			 v1.0.6 \
	github.com/kyoh86/exportloopref				 v0.1.8 \
	github.com/lann/builder					 v0.0.0-20180802200727-47ae307949d0 \
	github.com/lann/ps					 v0.0.0-20150810152359-62de8c46ede0 \
	github.com/ldez/gomoddirectives				 v0.2.3 \
	github.com/ldez/tagliatelle				 v0.3.1 \
	github.com/ledisdb/ledisdb				 v0.0.0-20200510135210-d35789ec47e6 \
	github.com/leonklingele/grouper				 v1.1.0 \
	github.com/lestrrat-go/backoff/v2			 v2.0.8 \
	github.com/lestrrat-go/blackmagic			 v1.0.0 \
	github.com/lestrrat-go/codegen				 v1.0.1 \
	github.com/lestrrat-go/httpcc				 v1.0.1 \
	github.com/lestrrat-go/iter				 v1.0.1 \
	github.com/lestrrat-go/jwx				 v1.2.25 \
	github.com/lestrrat-go/option				 v1.0.0 \
	github.com/lib/pq					 v1.10.6 \
	github.com/lufeee/execinquery				 v1.2.1 \
	github.com/lufia/plan9stats				 v0.0.0-20211012122336-39d0f177ccd0 \
	github.com/magefile/mage				 v1.13.0 \
	github.com/magiconair/properties			 v1.8.6 \
	github.com/maratori/testpackage				 v1.1.0 \
	github.com/matoous/go-nanoid				 v1.5.0 \
	github.com/matoous/godox				 v0.0.0-20210227103229-6504466cf951 \
	github.com/matryer/is					 v1.4.0 \
	github.com/mattn/go-colorable				 v0.1.13 \
	github.com/mattn/go-isatty				 v0.0.16 \
	github.com/mattn/go-runewidth				 v0.0.9 \
	github.com/mattn/go-sqlite3				 v1.14.15 \
	github.com/mattn/go-zglob				 v0.0.3 \
	github.com/matttproud/golang_protobuf_extensions	 v1.0.1 \
	github.com/mbilski/exhaustivestruct			 v1.2.0 \
	github.com/mgechev/dots					 v0.0.0-20210922191527-e955255bf517 \
	github.com/mgechev/revive				 v1.2.3 \
	github.com/microcosm-cc/bluemonday			 v1.0.20 \
	github.com/mileusna/useragent				 v1.2.1 \
	github.com/mitchellh/go-homedir				 v1.1.0 \
	github.com/mitchellh/go-ps				 v1.0.0 \
	github.com/mitchellh/mapstructure			 v1.5.0 \
	github.com/modern-go/concurrent				 v0.0.0-20180306012644-bacd9c7ef1dd \
	github.com/modern-go/reflect2				 v1.0.2 \
	github.com/moricho/tparallel				 v0.2.1 \
	github.com/mozilla/tls-observatory			 v0.0.0-20210609171429-7bc42856d2e5 \
	github.com/mwitkow/go-conntrack				 v0.0.0-20190716064945-2f068394615f \
	github.com/nakabonne/nestif				 v0.3.1 \
	github.com/nbutton23/zxcvbn-go				 v0.0.0-20210217022336-fa2cb2858354 \
	github.com/niemeyer/pretty				 v0.0.0-20200227124842-a10e7caefd8e \
	github.com/nishanths/exhaustive				 v0.8.1 \
	github.com/nishanths/predeclared			 v0.2.2 \
	github.com/nxadm/tail					 v1.4.8 \
	github.com/ogier/pflag					 v0.0.1 \
	github.com/oklog/run					 v1.1.0 \
	github.com/olekukonko/tablewriter			 v0.0.5 \
	github.com/onsi/ginkgo					 v1.16.5 \
	github.com/onsi/ginkgo/v2				 v2.2.0 \
	github.com/onsi/gomega					 v1.20.2 \
	github.com/opentracing/opentracing-go			 v1.2.0 \
	github.com/otiai10/copy					 v1.2.0 \
	github.com/otiai10/curr					 v1.0.0 \
	github.com/otiai10/mint					 v1.3.1 \
	github.com/pelletier/go-toml				 v1.9.5 \
	github.com/pelletier/go-toml/v2				 v2.0.5 \
	github.com/phayes/checkstyle				 v0.0.0-20170904204023-bfd46e6a821d \
	github.com/pierrec/lz4					 v2.0.5+incompatible \
	github.com/pkg/diff					 v0.0.0-20210226163009-20ebb0f2a09e \
	github.com/pkg/errors					 v0.9.1 \
	github.com/pkg/sftp					 v1.13.1 \
	github.com/pmezard/go-difflib				 v1.0.0 \
	github.com/polyfloyd/go-errorlint			 v1.0.2 \
	github.com/power-devops/perfstat			 v0.0.0-20210106213030-5aafc221ea8c \
	github.com/pressly/goose				 v2.7.0+incompatible \
	github.com/prometheus/client_golang			 v1.13.0 \
	github.com/prometheus/client_model			 v0.2.0 \
	github.com/prometheus/common				 v0.37.0 \
	github.com/prometheus/procfs				 v0.8.0 \
	github.com/quasilyte/go-ruleguard			 v0.3.17 \
	github.com/quasilyte/go-ruleguard/dsl			 v0.3.21 \
	github.com/quasilyte/go-ruleguard/rules			 v0.0.0-20211022131956-028d6511ab71 \
	github.com/quasilyte/gogrep				 v0.0.0-20220120141003-628d8b3623b5 \
	github.com/quasilyte/regex/syntax			 v0.0.0-20200407221936-30656e2c4a95 \
	github.com/quasilyte/stdinfo				 v0.0.0-20220114132959-f7386bf02567 \
	github.com/remyoudompheng/go-dbus			 v0.0.0-20121104212943-b7232d34b1d5 \
	github.com/remyoudompheng/go-liblzma			 v0.0.0-20190506200333-81bf2d431b96 \
	github.com/remyoudompheng/go-misc			 v0.0.0-20190427085024-2d6ac652a50e \
	github.com/robfig/cron/v3				 v3.0.1 \
	github.com/rogpeppe/go-internal				 v1.8.1 \
	github.com/russross/blackfriday/v2			 v2.1.0 \
	github.com/ryancurrah/gomodguard			 v1.2.4 \
	github.com/ryanrolds/sqlclosecheck			 v0.3.0 \
	github.com/sagikazarmark/crypt				 v0.6.0 \
	github.com/sanposhiho/wastedassign/v2			 v2.0.6 \
	github.com/sashamelentyev/interfacebloat		 v1.1.0 \
	github.com/sashamelentyev/usestdlibvars			 v1.13.0 \
	github.com/securego/gosec/v2				 v2.13.1 \
	github.com/shazow/go-diff				 v0.0.0-20160112020656-b6b7b6733b8c \
	github.com/shiena/ansicolor				 v0.0.0-20200904210342-c7312218db18 \
	github.com/shirou/gopsutil/v3				 v3.22.7 \
	github.com/shurcoo!l/go					 v0.0.0-20180423040247-9e1955d9fb6e \
	github.com/shurcoo!l/go-goon				 v0.0.0-20170922171312-37c2f522c041 \
	github.com/siddontang/go				 v0.0.0-20170517070808-cb568a3e5cc0 \
	github.com/siddontang/rdb				 v0.0.0-20150307021120-fc89ed2e418d \
	github.com/sirupsen/logrus				 v1.9.0 \
	github.com/sivchari/containedctx			 v1.0.2 \
	github.com/sivchari/nosnakecase				 v1.7.0 \
	github.com/sivchari/tenv				 v1.7.0 \
	github.com/smartystreets/assertions			 v0.0.0-20180927180507-b2de0cb4f26d \
	github.com/smartystreets/goconvey			 v1.6.4 \
	github.com/sonatard/noctx				 v0.0.1 \
	github.com/sourcegraph/go-diff				 v0.6.1 \
	github.com/spf13/afero					 v1.8.2 \
	github.com/spf13/cast					 v1.5.0 \
	github.com/spf13/cobra					 v1.5.0 \
	github.com/spf13/jwalterweatherman			 v1.1.0 \
	github.com/spf13/pflag					 v1.0.5 \
	github.com/spf13/viper					 v1.13.0 \
	github.com/ssdb/gossdb					 v0.0.0-20180723034631-88f6b59b84ec \
	github.com/ssgreg/nlreturn/v2				 v2.2.1 \
	github.com/stbenjam/no-sprintf-host-port		 v0.1.1 \
	github.com/stretchr/objx				 v0.4.0 \
	github.com/stretchr/testify				 v1.8.0 \
	github.com/subosito/gotenv				 v1.4.1 \
	github.com/sylvia7788/contextcheck			 v1.0.6 \
	github.com/syndtr/goleveldb				 v0.0.0-20160425020131-cfa635847112 \
	github.com/tdakkota/asciicheck				 v0.1.1 \
	github.com/tenntenn/modver				 v1.0.1 \
	github.com/tenntenn/text/transform			 v0.0.0-20200319021203-7eef512accb3 \
	github.com/tetafro/godot				 v1.4.11 \
	github.com/timakin/bodyclose				 v0.0.0-20210704033933-f49887972144 \
	github.com/timonwong/logrlint				 v0.1.0 \
	github.com/tklauser/go-sysconf				 v0.3.10 \
	github.com/tklauser/numcpus				 v0.4.0 \
	github.com/tomarrell/wrapcheck/v2			 v2.6.2 \
	github.com/tommy-muehle/go-mnd/v2			 v2.5.0 \
	github.com/ultraware/funlen				 v0.0.3 \
	github.com/ultraware/whitespace				 v0.0.5 \
	github.com/unrolled/secure				 v1.13.0 \
	github.com/uudashr/gocognit				 v1.0.6 \
	github.com/valyala/bytebufferpool			 v1.0.0 \
	github.com/valyala/quicktemplate			 v1.7.0 \
	github.com/xo/terminfo					 v0.0.0-20210125001918-ca9a967f8778 \
	github.com/xrash/smetrics				 v0.0.0-20200730060457-89a2a8a1fb0b \
	github.com/yagipy/maintidx				 v1.0.0 \
	github.com/yeya24/promlinter				 v0.2.0 \
	github.com/yuin/goldmark				 v1.4.13 \
	github.com/yusufpapurcu/wmi				 v1.2.2 \
	github.com/ziutek/mymysql				 v1.5.4 \
	gitlab.com/bosi/decorder				 v0.2.3 \
	go.etcd.io/etcd/api/v3					 v3.5.4 \
	go.etcd.io/etcd/client/pkg/v3				 v3.5.4 \
	go.etcd.io/etcd/client/v2				 v2.305.4 \
	go.etcd.io/etcd/client/v3				 v3.5.4 \
	go.opencensus.io					 v0.23.0 \
	go.opentelemetry.io/otel				 v1.8.0 \
	go.opentelemetry.io/otel/exporters/stdout/stdouttrace	 v1.8.0 \
	go.opentelemetry.io/otel/sdk				 v1.8.0 \
	go.opentelemetry.io/otel/trace				 v1.8.0 \
	go.uber.org/atomic					 v1.7.0 \
	go.uber.org/goleak					 v1.1.10 \
	go.uber.org/multierr					 v1.6.0 \
	go.uber.org/zap						 v1.17.0 \
	golang.org/x/crypto					 v0.0.0-20220722155217-630584e8d5aa \
	golang.org/x/exp					 v0.0.0-20220722155223-a9213eeb770e \
	golang.org/x/exp/typeparams				 v0.0.0-20220613132600-b0d781184e0d \
	golang.org/x/image					 v0.0.0-20191009234506-e7c1f5e7dbb8 \
	golang.org/x/lint					 v0.0.0-20210508222113-6edffad5e616 \
	golang.org/x/mobile					 v0.0.0-20190719004257-d2bd2a29d028 \
	golang.org/x/mod					 v0.6.0-dev.0.20220419223038-86c51ed26bb4 \
	golang.org/x/net					 v0.0.0-20220826154423-83b083e8dc8b \
	golang.org/x/oauth2					 v0.0.0-20220411215720-9780585627b5 \
	golang.org/x/sync					 v0.0.0-20220722155255-886fb9371eb4 \
	golang.org/x/sys					 v0.0.0-20220811171246-fbc7d0a398ab \
	golang.org/x/term					 v0.0.0-20210927222741-03fcf44c2211 \
	golang.org/x/text					 v0.3.7 \
	golang.org/x/time					 v0.0.0-20191024005414-555d28b269f0 \
	golang.org/x/tools					 v0.1.12 \
	golang.org/x/xerrors					 v0.0.0-20220517211312-f3a8303e98df \
	google.golang.org/api					 v0.81.0 \
	google.golang.org/appengine				 v1.6.7 \
	google.golang.org/genproto				 v0.0.0-20220519153652-3a47de7e79bd \
	google.golang.org/grpc					 v1.46.2 \
	google.golang.org/protobuf				 v1.28.1 \
	gopkg.in/alecthomas/kingpin.v2				 v2.2.6 \
	gopkg.in/check.v1					 v1.0.0-20200227125254-8fa46927fb4f \
	gopkg.in/errgo.v2					 v2.1.0 \
	gopkg.in/fsnotify.v1					 v1.4.7 \
	gopkg.in/ini.v1						 v1.67.0 \
	gopkg.in/tomb.v1					 v1.0.0-20141024135613-dd632973f1e7 \
	gopkg.in/yaml.v2					 v2.4.0 \
	gopkg.in/yaml.v3					 v3.0.1 \
	honnef.co/go/tools					 v0.3.3 \
	mvdan.cc/gofumpt					 v0.3.1 \
	mvdan.cc/interfacer					 v0.0.0-20180901003855-c20040233aed \
	mvdan.cc/lint						 v0.0.0-20170908181259-adc824a0674b \
	mvdan.cc/unparam					 v0.0.0-20220706161116-678bad134442 \
	rsc.io/binaryregexp					 v0.2.0 \
	rsc.io/quote/v3						 v3.1.0 \
	rsc.io/sampler						 v1.3.0

MODGO_MODFILES =	\
	cloud.google.com/go					 v0.26.0 \
	cloud.google.com/go					 v0.34.0 \
	cloud.google.com/go					 v0.38.0 \
	cloud.google.com/go					 v0.44.1 \
	cloud.google.com/go					 v0.44.2 \
	cloud.google.com/go					 v0.44.3 \
	cloud.google.com/go					 v0.45.1 \
	cloud.google.com/go					 v0.46.3 \
	cloud.google.com/go					 v0.50.0 \
	cloud.google.com/go					 v0.52.0 \
	cloud.google.com/go					 v0.53.0 \
	cloud.google.com/go					 v0.54.0 \
	cloud.google.com/go					 v0.56.0 \
	cloud.google.com/go					 v0.57.0 \
	cloud.google.com/go					 v0.62.0 \
	cloud.google.com/go					 v0.65.0 \
	cloud.google.com/go					 v0.72.0 \
	cloud.google.com/go					 v0.74.0 \
	cloud.google.com/go					 v0.75.0 \
	cloud.google.com/go/bigquery				 v1.0.1 \
	cloud.google.com/go/bigquery				 v1.3.0 \
	cloud.google.com/go/bigquery				 v1.4.0 \
	cloud.google.com/go/bigquery				 v1.5.0 \
	cloud.google.com/go/bigquery				 v1.7.0 \
	cloud.google.com/go/datastore				 v1.0.0 \
	cloud.google.com/go/pubsub				 v1.0.1 \
	cloud.google.com/go/pubsub				 v1.1.0 \
	cloud.google.com/go/pubsub				 v1.2.0 \
	cloud.google.com/go/storage				 v1.0.0 \
	cloud.google.com/go/storage				 v1.10.0 \
	cloud.google.com/go/storage				 v1.5.0 \
	cloud.google.com/go/storage				 v1.6.0 \
	cloud.google.com/go/storage				 v1.8.0 \
	github.com/!burnt!sushi/toml				 v0.3.1 \
	github.com/!burnt!sushi/toml				 v0.4.1 \
	github.com/alecthomas/template				 v0.0.0-20160405071501-a0175ee3bccc \
	github.com/alecthomas/units				 v0.0.0-20151022065526-2efee857e7cf \
	github.com/alecthomas/units				 v0.0.0-20190717042225-c3de453c63f4 \
	github.com/beorn7/perks					 v0.0.0-20180321164747-3a771d992973 \
	github.com/beorn7/perks					 v1.0.0 \
	github.com/cespare/xxhash/v2				 v2.1.1 \
	github.com/chzyer/readline				 v0.0.0-20180603132655-2972be24d48e \
	github.com/cncf/udpa/go					 v0.0.0-20191209042840-269d4d468f6f \
	github.com/cncf/udpa/go					 v0.0.0-20200629203442-efcf912fb354 \
	github.com/creack/pty					 v1.1.9 \
	github.com/davecgh/go-spew				 v1.1.0 \
	github.com/envoyproxy/go-control-plane			 v0.9.0 \
	github.com/envoyproxy/go-control-plane			 v0.9.1-0.20191026205805-5f8ba28d4473 \
	github.com/envoyproxy/go-control-plane			 v0.9.4 \
	github.com/envoyproxy/go-control-plane			 v0.9.7 \
	github.com/frankban/quicktest				 v1.14.2 \
	github.com/fsnotify/fsnotify				 v1.4.7 \
	github.com/fsnotify/fsnotify				 v1.4.9 \
	github.com/go-chi/chi/v5				 v5.0.4 \
	github.com/go-gl/glfw/v3.3/glfw				 v0.0.0-20191125211704-12ad95a8df72 \
	github.com/go-kit/kit					 v0.8.0 \
	github.com/go-kit/kit					 v0.9.0 \
	github.com/go-kit/log					 v0.1.0 \
	github.com/go-logfmt/logfmt				 v0.3.0 \
	github.com/go-logfmt/logfmt				 v0.4.0 \
	github.com/go-logfmt/logfmt				 v0.5.0 \
	github.com/go-sql-driver/mysql				 v1.4.0 \
	github.com/go-toolsmith/astcopy				 v1.0.0 \
	github.com/go-toolsmith/astequal			 v1.0.0 \
	github.com/go-toolsmith/astequal			 v1.0.1 \
	github.com/goccy/go-json				 v0.7.6 \
	github.com/gogo/protobuf				 v1.1.1 \
	github.com/golang/groupcache				 v0.0.0-20190702054246-869f871628b6 \
	github.com/golang/groupcache				 v0.0.0-20191227052852-215e87163ea7 \
	github.com/golang/groupcache				 v0.0.0-20200121045136-8c9f03a8e57e \
	github.com/golang/mock					 v1.1.1 \
	github.com/golang/mock					 v1.2.0 \
	github.com/golang/mock					 v1.3.1 \
	github.com/golang/mock					 v1.4.0 \
	github.com/golang/mock					 v1.4.1 \
	github.com/golang/mock					 v1.4.3 \
	github.com/golang/protobuf				 v1.2.0 \
	github.com/golang/protobuf				 v1.3.1 \
	github.com/golang/protobuf				 v1.3.2 \
	github.com/golang/protobuf				 v1.3.3 \
	github.com/golang/protobuf				 v1.3.4 \
	github.com/golang/protobuf				 v1.3.5 \
	github.com/golang/protobuf				 v1.4.0 \
	github.com/golang/protobuf				 v1.4.0-rc.1 \
	github.com/golang/protobuf				 v1.4.0-rc.1.0.20200221234624-67d41d38c208 \
	github.com/golang/protobuf				 v1.4.0-rc.2 \
	github.com/golang/protobuf				 v1.4.0-rc.4.0.20200313231945-b860323f09d0 \
	github.com/golang/protobuf				 v1.4.1 \
	github.com/golang/protobuf				 v1.4.2 \
	github.com/golang/protobuf				 v1.4.3 \
	github.com/golang/protobuf				 v1.5.0 \
	github.com/google/btree					 v0.0.0-20180813153112-4030bb1f1f0c \
	github.com/google/go-cmp				 v0.2.0 \
	github.com/google/go-cmp				 v0.3.0 \
	github.com/google/go-cmp				 v0.3.1 \
	github.com/google/go-cmp				 v0.4.0 \
	github.com/google/go-cmp				 v0.4.1 \
	github.com/google/go-cmp				 v0.5.0 \
	github.com/google/go-cmp				 v0.5.1 \
	github.com/google/go-cmp				 v0.5.2 \
	github.com/google/go-cmp				 v0.5.4 \
	github.com/google/go-cmp				 v0.5.5 \
	github.com/google/go-cmp				 v0.5.6 \
	github.com/google/go-cmp				 v0.5.7 \
	github.com/google/martian/v3				 v3.0.0 \
	github.com/google/pprof					 v0.0.0-20181206194817-3ea8567a2e57 \
	github.com/google/pprof					 v0.0.0-20190515194954-54271f7e092f \
	github.com/google/pprof					 v0.0.0-20191218002539-d4f498aebedc \
	github.com/google/pprof					 v0.0.0-20200212024743-f11f1df84d12 \
	github.com/google/pprof					 v0.0.0-20200229191704-1ebb73c60ed3 \
	github.com/google/pprof					 v0.0.0-20200430221834-fc25d7d30c6d \
	github.com/google/pprof					 v0.0.0-20200708004538-1a94d8640e99 \
	github.com/google/pprof					 v0.0.0-20201023163331-3e6fc7fc9c4c \
	github.com/google/pprof					 v0.0.0-20201203190320-1bf35d6f28c2 \
	github.com/google/pprof					 v0.0.0-20201218002935-b9804c9f04c2 \
	github.com/google/pprof					 v0.0.0-20210407192527-94a9f03dee38 \
	github.com/google/uuid					 v1.1.2 \
	github.com/google/uuid					 v1.2.0 \
	github.com/googleapis/gax-go/v2				 v2.0.4 \
	github.com/googleapis/gax-go/v2				 v2.0.5 \
	github.com/gostaticanalysis/analysisutil		 v0.0.0-20190318220348-4088753ea4d3 \
	github.com/gostaticanalysis/analysisutil		 v0.0.3 \
	github.com/gostaticanalysis/analysisutil		 v0.1.0 \
	github.com/gostaticanalysis/analysisutil		 v0.4.1 \
	github.com/gostaticanalysis/comment			 v1.3.0 \
	github.com/gostaticanalysis/comment			 v1.4.1 \
	github.com/gostaticanalysis/testutil			 v0.3.1-0.20210208050101-bfb5c8eec0e4 \
	github.com/hashicorp/go-version				 v1.2.1 \
	github.com/hashicorp/golang-lru				 v0.5.0 \
	github.com/hashicorp/golang-lru				 v0.5.1 \
	github.com/ianlancetaylor/demangle			 v0.0.0-20181102032728-5e5cf60278f6 \
	github.com/ianlancetaylor/demangle			 v0.0.0-20200824232613-28f6c0f3b639 \
	github.com/json-iterator/go				 v1.1.10 \
	github.com/json-iterator/go				 v1.1.11 \
	github.com/json-iterator/go				 v1.1.6 \
	github.com/jstemmer/go-junit-report			 v0.0.0-20190106144839-af01ea7f8024 \
	github.com/julienschmidt/httprouter			 v1.2.0 \
	github.com/konsorten/go-windows-terminal-sequences	 v1.0.1 \
	github.com/kr/pretty					 v0.1.0 \
	github.com/kr/text					 v0.1.0 \
	github.com/lestrrat-go/httpcc				 v1.0.0 \
	github.com/lestrrat-go/jwx				 v1.2.6 \
	github.com/lib/pq					 v1.0.0 \
	github.com/lib/pq					 v1.10.5 \
	github.com/mattn/go-colorable				 v0.1.12 \
	github.com/mattn/go-colorable				 v0.1.9 \
	github.com/mattn/go-isatty				 v0.0.12 \
	github.com/mattn/go-isatty				 v0.0.14 \
	github.com/mattn/go-sqlite3				 v1.14.7 \
	github.com/mattn/go-sqlite3				 v1.9.0 \
	github.com/mitchellh/mapstructure			 v1.4.3 \
	github.com/modern-go/concurrent				 v0.0.0-20180228061459-e0a39a4cb421 \
	github.com/modern-go/reflect2				 v0.0.0-20180701023420-4b7aa43c6742 \
	github.com/modern-go/reflect2				 v1.0.1 \
	github.com/mwitkow/go-conntrack				 v0.0.0-20161129095857-cc309e4a2223 \
	github.com/nxadm/tail					 v1.4.4 \
	github.com/onsi/ginkgo					 v1.12.1 \
	github.com/onsi/ginkgo					 v1.6.0 \
	github.com/onsi/ginkgo/v2				 v2.1.4 \
	github.com/onsi/ginkgo/v2				 v2.1.6 \
	github.com/onsi/gomega					 v1.10.1 \
	github.com/onsi/gomega					 v1.20.0 \
	github.com/onsi/gomega					 v1.20.1 \
	github.com/onsi/gomega					 v1.7.1 \
	github.com/otiai10/curr					 v0.0.0-20150429015615-9b4961190c95 \
	github.com/otiai10/mint					 v1.3.0 \
	github.com/pelletier/go-toml				 v1.9.2 \
	github.com/pelletier/go-toml/v2				 v2.0.2 \
	github.com/pkg/errors					 v0.8.0 \
	github.com/pkg/errors					 v0.8.1 \
	github.com/prometheus/client_golang			 v0.9.1 \
	github.com/prometheus/client_golang			 v1.0.0 \
	github.com/prometheus/client_golang			 v1.11.0 \
	github.com/prometheus/client_golang			 v1.12.1 \
	github.com/prometheus/client_golang			 v1.7.1 \
	github.com/prometheus/client_model			 v0.0.0-20180712105110-5c3871d89910 \
	github.com/prometheus/client_model			 v0.0.0-20190129233127-fd36f4220a90 \
	github.com/prometheus/client_model			 v0.0.0-20190812154241-14fe0d1b01d4 \
	github.com/prometheus/common				 v0.10.0 \
	github.com/prometheus/common				 v0.26.0 \
	github.com/prometheus/common				 v0.32.1 \
	github.com/prometheus/common				 v0.4.1 \
	github.com/prometheus/procfs				 v0.0.0-20181005140218-185b4288413d \
	github.com/prometheus/procfs				 v0.0.2 \
	github.com/prometheus/procfs				 v0.1.3 \
	github.com/prometheus/procfs				 v0.6.0 \
	github.com/prometheus/procfs				 v0.7.3 \
	github.com/quasilyte/go-ruleguard			 v0.3.1-0.20210203134552-1b5a410e1cc8 \
	github.com/quasilyte/go-ruleguard/dsl			 v0.3.0 \
	github.com/quasilyte/go-ruleguard/rules			 v0.0.0-20201231183845-9e62ed36efe1 \
	github.com/rogpeppe/go-internal				 v1.3.0 \
	github.com/rogpeppe/go-internal				 v1.6.1 \
	github.com/sirupsen/logrus				 v1.2.0 \
	github.com/sirupsen/logrus				 v1.4.2 \
	github.com/sirupsen/logrus				 v1.6.0 \
	github.com/spf13/cobra					 v1.3.0 \
	github.com/spf13/viper					 v1.12.0 \
	github.com/stretchr/objx				 v0.1.0 \
	github.com/stretchr/objx				 v0.1.1 \
	github.com/stretchr/testify				 v1.1.4 \
	github.com/stretchr/testify				 v1.2.2 \
	github.com/stretchr/testify				 v1.3.0 \
	github.com/stretchr/testify				 v1.4.0 \
	github.com/stretchr/testify				 v1.5.1 \
	github.com/stretchr/testify				 v1.6.1 \
	github.com/stretchr/testify				 v1.7.0 \
	github.com/stretchr/testify				 v1.7.1 \
	github.com/stretchr/testify				 v1.7.2 \
	github.com/stretchr/testify				 v1.7.5 \
	github.com/subosito/gotenv				 v1.4.0 \
	github.com/yuin/goldmark				 v1.1.25 \
	github.com/yuin/goldmark				 v1.1.27 \
	github.com/yuin/goldmark				 v1.1.32 \
	github.com/yuin/goldmark				 v1.2.1 \
	github.com/yuin/goldmark				 v1.3.5 \
	github.com/yuin/goldmark				 v1.4.1 \
	go.opencensus.io					 v0.21.0 \
	go.opencensus.io					 v0.22.0 \
	go.opencensus.io					 v0.22.2 \
	go.opencensus.io					 v0.22.3 \
	go.opencensus.io					 v0.22.4 \
	go.opencensus.io					 v0.22.5 \
	golang.org/x/crypto					 v0.0.0-20180904163835-0709b304e793 \
	golang.org/x/crypto					 v0.0.0-20190308221718-c2843e01d9a2 \
	golang.org/x/crypto					 v0.0.0-20190325154230-a5d413f7728c \
	golang.org/x/crypto					 v0.0.0-20190510104115-cbcb75029529 \
	golang.org/x/crypto					 v0.0.0-20190605123033-f99c8df09eb5 \
	golang.org/x/crypto					 v0.0.0-20191011191535-87dc89f01550 \
	golang.org/x/crypto					 v0.0.0-20200622213623-75b288015ac9 \
	golang.org/x/crypto					 v0.0.0-20201217014255-9d1352758620 \
	golang.org/x/crypto					 v0.0.0-20210421170649-83a5a9bb288b \
	golang.org/x/crypto					 v0.0.0-20210513164829-c07d793c2f9a \
	golang.org/x/crypto					 v0.0.0-20210921155107-089bfa567519 \
	golang.org/x/crypto					 v0.0.0-20211108221036-ceb1ce70b4fa \
	golang.org/x/crypto					 v0.0.0-20220411220226-7b82a4e95df4 \
	golang.org/x/crypto					 v0.0.0-20220427172511-eb4f295cb31f \
	golang.org/x/exp					 v0.0.0-20190121172915-509febef88a4 \
	golang.org/x/exp					 v0.0.0-20190306152737-a1d7652674e8 \
	golang.org/x/exp					 v0.0.0-20190510132918-efd6b22b2522 \
	golang.org/x/exp					 v0.0.0-20190829153037-c13cbed26979 \
	golang.org/x/exp					 v0.0.0-20191030013958-a1ab85dbe136 \
	golang.org/x/exp					 v0.0.0-20191129062945-2f5052295587 \
	golang.org/x/exp					 v0.0.0-20191227195350-da58074b4299 \
	golang.org/x/exp					 v0.0.0-20200119233911-0405dc783f0a \
	golang.org/x/exp					 v0.0.0-20200207192155-f17229e696bd \
	golang.org/x/exp					 v0.0.0-20200224162631-6cc2880d07d6 \
	golang.org/x/exp/typeparams				 v0.0.0-20220218215828-6cf2b201936e \
	golang.org/x/exp/typeparams				 v0.0.0-20220428152302-39d4317da171 \
	golang.org/x/image					 v0.0.0-20190227222117-0694c2d4d067 \
	golang.org/x/image					 v0.0.0-20190802002840-cff245a6509b \
	golang.org/x/lint					 v0.0.0-20181026193005-c67002cb31c3 \
	golang.org/x/lint					 v0.0.0-20190227174305-5b3e6a55c961 \
	golang.org/x/lint					 v0.0.0-20190301231843-5614ed5bae6f \
	golang.org/x/lint					 v0.0.0-20190313153728-d0100b6bd8b3 \
	golang.org/x/lint					 v0.0.0-20190409202823-959b441ac422 \
	golang.org/x/lint					 v0.0.0-20190909230951-414d861bb4ac \
	golang.org/x/lint					 v0.0.0-20190930215403-16217165b5de \
	golang.org/x/lint					 v0.0.0-20191125180803-fdd1cda4f05f \
	golang.org/x/lint					 v0.0.0-20200130185559-910be7a94367 \
	golang.org/x/lint					 v0.0.0-20200302205851-738671d3881b \
	golang.org/x/lint					 v0.0.0-20201208152925-83fdc39ff7b5 \
	golang.org/x/mobile					 v0.0.0-20190312151609-d3739f865fa6 \
	golang.org/x/mod					 v0.0.0-20190513183733-4bf6d317e70e \
	golang.org/x/mod					 v0.1.0 \
	golang.org/x/mod					 v0.1.1-0.20191105210325-c90efee705ee \
	golang.org/x/mod					 v0.1.1-0.20191107180719-034126e5016b \
	golang.org/x/mod					 v0.2.0 \
	golang.org/x/mod					 v0.3.0 \
	golang.org/x/mod					 v0.4.0 \
	golang.org/x/mod					 v0.4.1 \
	golang.org/x/mod					 v0.4.2 \
	golang.org/x/mod					 v0.5.0 \
	golang.org/x/mod					 v0.5.1 \
	golang.org/x/mod					 v0.6.0-dev.0.20220106191415-9b9b3d81d5e3 \
	golang.org/x/net					 v0.0.0-20180724234803-3673e40ba225 \
	golang.org/x/net					 v0.0.0-20180826012351-8a410e7b638d \
	golang.org/x/net					 v0.0.0-20180906233101-161cd47e91fd \
	golang.org/x/net					 v0.0.0-20181114220301-adae6a3d119a \
	golang.org/x/net					 v0.0.0-20190108225652-1e06a53dbb7e \
	golang.org/x/net					 v0.0.0-20190213061140-3a22650c66bd \
	golang.org/x/net					 v0.0.0-20190311183353-d8887717615a \
	golang.org/x/net					 v0.0.0-20190404232315-eb5bcb51f2a3 \
	golang.org/x/net					 v0.0.0-20190501004415-9ce7a6920f09 \
	golang.org/x/net					 v0.0.0-20190503192946-f4e77d36d62c \
	golang.org/x/net					 v0.0.0-20190603091049-60506f45cf65 \
	golang.org/x/net					 v0.0.0-20190613194153-d28f0bde5980 \
	golang.org/x/net					 v0.0.0-20190620200207-3b0461eec859 \
	golang.org/x/net					 v0.0.0-20190628185345-da137c7871d7 \
	golang.org/x/net					 v0.0.0-20190724013045-ca1201d0de80 \
	golang.org/x/net					 v0.0.0-20191209160850-c0dbc17a3553 \
	golang.org/x/net					 v0.0.0-20200114155413-6afb5195e5aa \
	golang.org/x/net					 v0.0.0-20200202094626-16171245cfb2 \
	golang.org/x/net					 v0.0.0-20200222125558-5a598a2470a0 \
	golang.org/x/net					 v0.0.0-20200226121028-0de0cce0169b \
	golang.org/x/net					 v0.0.0-20200301022130-244492dfa37a \
	golang.org/x/net					 v0.0.0-20200324143707-d3edc9973b7e \
	golang.org/x/net					 v0.0.0-20200501053045-e0ff5e5a1de5 \
	golang.org/x/net					 v0.0.0-20200506145744-7e3656a0809f \
	golang.org/x/net					 v0.0.0-20200513185701-a91f0712d120 \
	golang.org/x/net					 v0.0.0-20200520004742-59133d7f0dd7 \
	golang.org/x/net					 v0.0.0-20200520182314-0ba52f642ac2 \
	golang.org/x/net					 v0.0.0-20200625001655-4c5254603344 \
	golang.org/x/net					 v0.0.0-20200707034311-ab3426394381 \
	golang.org/x/net					 v0.0.0-20200822124328-c89045814202 \
	golang.org/x/net					 v0.0.0-20201021035429-f5854403a974 \
	golang.org/x/net					 v0.0.0-20201031054903-ff519b6c9102 \
	golang.org/x/net					 v0.0.0-20201209123823-ac852fbbde11 \
	golang.org/x/net					 v0.0.0-20201224014010-6772e930b67b \
	golang.org/x/net					 v0.0.0-20210226172049-e18ecbb05110 \
	golang.org/x/net					 v0.0.0-20210405180319-a5a99cb37ef4 \
	golang.org/x/net					 v0.0.0-20210525063256-abc453219eb5 \
	golang.org/x/net					 v0.0.0-20211015210444-4f30a5c0130f \
	golang.org/x/net					 v0.0.0-20211112202133-69e39bad7dc2 \
	golang.org/x/net					 v0.0.0-20220127200216-cd36cc0744dd \
	golang.org/x/net					 v0.0.0-20220225172249-27dd8689420f \
	golang.org/x/net					 v0.0.0-20220325170049-de3da57026de \
	golang.org/x/net					 v0.0.0-20220520000938-2e3eb7b945c2 \
	golang.org/x/net					 v0.0.0-20220722155237-a158d28d115b \
	golang.org/x/oauth2					 v0.0.0-20180821212333-d2e6202438be \
	golang.org/x/oauth2					 v0.0.0-20190226205417-e64efc72b421 \
	golang.org/x/oauth2					 v0.0.0-20190604053449-0f29369cfe45 \
	golang.org/x/oauth2					 v0.0.0-20191202225959-858c2ad4c8b6 \
	golang.org/x/oauth2					 v0.0.0-20200107190931-bf48bf16ab8d \
	golang.org/x/oauth2					 v0.0.0-20200902213428-5d25da1a8d43 \
	golang.org/x/oauth2					 v0.0.0-20201109201403-9fd604954f58 \
	golang.org/x/oauth2					 v0.0.0-20201208152858-08078c50e5b5 \
	golang.org/x/oauth2					 v0.0.0-20210218202405-ba52d332ba99 \
	golang.org/x/oauth2					 v0.0.0-20210514164344-f6687ab2804c \
	golang.org/x/oauth2					 v0.0.0-20220223155221-ee480838109b \
	golang.org/x/sync					 v0.0.0-20180314180146-1d60e4601c6f \
	golang.org/x/sync					 v0.0.0-20181108010431-42b317875d0f \
	golang.org/x/sync					 v0.0.0-20181221193216-37e7f081c4d4 \
	golang.org/x/sync					 v0.0.0-20190227155943-e225da77a7e6 \
	golang.org/x/sync					 v0.0.0-20190423024810-112230192c58 \
	golang.org/x/sync					 v0.0.0-20190911185100-cd5d95a43a6e \
	golang.org/x/sync					 v0.0.0-20200317015054-43a5402ce75a \
	golang.org/x/sync					 v0.0.0-20200625203802-6e8e738ad208 \
	golang.org/x/sync					 v0.0.0-20201020160332-67f06af15bc9 \
	golang.org/x/sync					 v0.0.0-20201207232520-09787c993a3a \
	golang.org/x/sync					 v0.0.0-20210220032951-036812b2e83c \
	golang.org/x/sync					 v0.0.0-20220601150217-0de741cfad7f \
	golang.org/x/sys					 v0.0.0-20180830151530-49385e6e1522 \
	golang.org/x/sys					 v0.0.0-20180905080454-ebe1bf3edb33 \
	golang.org/x/sys					 v0.0.0-20180909124046-d0be0721c37e \
	golang.org/x/sys					 v0.0.0-20181116152217-5ac8a444bdc5 \
	golang.org/x/sys					 v0.0.0-20190215142949-d0b11bdaac8a \
	golang.org/x/sys					 v0.0.0-20190312061237-fead79001313 \
	golang.org/x/sys					 v0.0.0-20190412213103-97732733099d \
	golang.org/x/sys					 v0.0.0-20190422165155-953cdadca894 \
	golang.org/x/sys					 v0.0.0-20190502145724-3ef323f4f1fd \
	golang.org/x/sys					 v0.0.0-20190507160741-ecd444e8653b \
	golang.org/x/sys					 v0.0.0-20190606165138-5da285871e9c \
	golang.org/x/sys					 v0.0.0-20190624142023-c5567b49c5d0 \
	golang.org/x/sys					 v0.0.0-20190726091711-fc99dfbffb4e \
	golang.org/x/sys					 v0.0.0-20190904154756-749cb33beabd \
	golang.org/x/sys					 v0.0.0-20191001151750-bb3f8db39f24 \
	golang.org/x/sys					 v0.0.0-20191005200804-aed5e4c7ecf9 \
	golang.org/x/sys					 v0.0.0-20191026070338-33540a1f6037 \
	golang.org/x/sys					 v0.0.0-20191120155948-bd437916bb0e \
	golang.org/x/sys					 v0.0.0-20191204072324-ce4227a45e2e \
	golang.org/x/sys					 v0.0.0-20191228213918-04cbcbbfeed8 \
	golang.org/x/sys					 v0.0.0-20200106162015-b016eb3dc98e \
	golang.org/x/sys					 v0.0.0-20200113162924-86b910548bc1 \
	golang.org/x/sys					 v0.0.0-20200116001909-b77594299b42 \
	golang.org/x/sys					 v0.0.0-20200122134326-e047566fdf82 \
	golang.org/x/sys					 v0.0.0-20200202164722-d101bd2416d5 \
	golang.org/x/sys					 v0.0.0-20200212091648-12a6c2dcc1e4 \
	golang.org/x/sys					 v0.0.0-20200223170610-d5e6a3e2c0ae \
	golang.org/x/sys					 v0.0.0-20200302150141-5c8b2ff67527 \
	golang.org/x/sys					 v0.0.0-20200323222414-85ca7c5b95cd \
	golang.org/x/sys					 v0.0.0-20200331124033-c3d80250170d \
	golang.org/x/sys					 v0.0.0-20200501052902-10377860bb8e \
	golang.org/x/sys					 v0.0.0-20200511232937-7e40ca221e25 \
	golang.org/x/sys					 v0.0.0-20200515095857-1151b9dac4a9 \
	golang.org/x/sys					 v0.0.0-20200523222454-059865788121 \
	golang.org/x/sys					 v0.0.0-20200615200032-f1bc736245b1 \
	golang.org/x/sys					 v0.0.0-20200625212154-ddb9806d33ae \
	golang.org/x/sys					 v0.0.0-20200803210538-64077c9b5642 \
	golang.org/x/sys					 v0.0.0-20200905004654-be1d3432aa8f \
	golang.org/x/sys					 v0.0.0-20200930185726-fdedc70b468f \
	golang.org/x/sys					 v0.0.0-20201119102817-f84b799fce68 \
	golang.org/x/sys					 v0.0.0-20201201145000-ef89a241ccb3 \
	golang.org/x/sys					 v0.0.0-20210104204734-6f8348627aad \
	golang.org/x/sys					 v0.0.0-20210112080510-489259a85091 \
	golang.org/x/sys					 v0.0.0-20210119212857-b64e53b001e4 \
	golang.org/x/sys					 v0.0.0-20210124154548-22da62e12c0c \
	golang.org/x/sys					 v0.0.0-20210225134936-a50acf3fe073 \
	golang.org/x/sys					 v0.0.0-20210330210617-4fbd30eecc44 \
	golang.org/x/sys					 v0.0.0-20210423082822-04245dca01da \
	golang.org/x/sys					 v0.0.0-20210423185535-09eb48e85fd7 \
	golang.org/x/sys					 v0.0.0-20210510120138-977fb7262007 \
	golang.org/x/sys					 v0.0.0-20210603081109-ebe580a85c40 \
	golang.org/x/sys					 v0.0.0-20210615035016-665e8c7367d1 \
	golang.org/x/sys					 v0.0.0-20210630005230-0f9fa26af87c \
	golang.org/x/sys					 v0.0.0-20210809222454-d867a43fc93e \
	golang.org/x/sys					 v0.0.0-20211019181941-9d821ace8654 \
	golang.org/x/sys					 v0.0.0-20211105183446-c75c47738b0c \
	golang.org/x/sys					 v0.0.0-20211216021012-1d35b9e2eb4e \
	golang.org/x/sys					 v0.0.0-20220114195835-da31bd327af9 \
	golang.org/x/sys					 v0.0.0-20220310020820-b874c991c1a5 \
	golang.org/x/sys					 v0.0.0-20220319134239-a9b59b0215f8 \
	golang.org/x/sys					 v0.0.0-20220406163625-3f8b81556e12 \
	golang.org/x/sys					 v0.0.0-20220412211240-33da011f77ad \
	golang.org/x/sys					 v0.0.0-20220520151302-bc2c85ada10a \
	golang.org/x/sys					 v0.0.0-20220610221304-9f5ed59c137d \
	golang.org/x/sys					 v0.0.0-20220615213510-4f61da869c0c \
	golang.org/x/sys					 v0.0.0-20220624220833-87e55d714810 \
	golang.org/x/sys					 v0.0.0-20220627191245-f75cf1eec38b \
	golang.org/x/sys					 v0.0.0-20220702020025-31831981b65f \
	golang.org/x/sys					 v0.0.0-20220715151400-c0bba94af5f8 \
	golang.org/x/sys					 v0.0.0-20220722155257-8c9f86f7a55f \
	golang.org/x/sys					 v0.0.0-20220728004956-3c1f35247d10 \
	golang.org/x/term					 v0.0.0-20201117132131-f5c789dd3221 \
	golang.org/x/term					 v0.0.0-20201126162022-7de9c90e9dd1 \
	golang.org/x/text					 v0.0.0-20170915032832-14c0d48ead0c \
	golang.org/x/text					 v0.3.0 \
	golang.org/x/text					 v0.3.1-0.20180807135948-17ff2d5776d2 \
	golang.org/x/text					 v0.3.2 \
	golang.org/x/text					 v0.3.3 \
	golang.org/x/text					 v0.3.4 \
	golang.org/x/text					 v0.3.6 \
	golang.org/x/time					 v0.0.0-20181108054448-85acf8d2951c \
	golang.org/x/time					 v0.0.0-20190308202827-9d24e82272b4 \
	golang.org/x/tools					 v0.0.0-20180525024113-a5b4c53f6e8b \
	golang.org/x/tools					 v0.0.0-20180917221912-90fa682c2a6e \
	golang.org/x/tools					 v0.0.0-20190114222345-bf090417da8b \
	golang.org/x/tools					 v0.0.0-20190226205152-f727befe758c \
	golang.org/x/tools					 v0.0.0-20190307163923-6a08e3108db3 \
	golang.org/x/tools					 v0.0.0-20190311212946-11955173bddd \
	golang.org/x/tools					 v0.0.0-20190311215038-5c2858a9cfe5 \
	golang.org/x/tools					 v0.0.0-20190312151545-0bb0c0a6e846 \
	golang.org/x/tools					 v0.0.0-20190312170243-e65039ee4138 \
	golang.org/x/tools					 v0.0.0-20190321232350-e250d351ecad \
	golang.org/x/tools					 v0.0.0-20190322203728-c1a832b0ad89 \
	golang.org/x/tools					 v0.0.0-20190328211700-ab21143f2384 \
	golang.org/x/tools					 v0.0.0-20190422233926-fe54fb35175b \
	golang.org/x/tools					 v0.0.0-20190425150028-36563e24a262 \
	golang.org/x/tools					 v0.0.0-20190506145303-2d16b83fe98c \
	golang.org/x/tools					 v0.0.0-20190524140312-2c0ae7006135 \
	golang.org/x/tools					 v0.0.0-20190606124116-d0a3d012864b \
	golang.org/x/tools					 v0.0.0-20190621195816-6e04913cbbac \
	golang.org/x/tools					 v0.0.0-20190628153133-6cdbf07be9d0 \
	golang.org/x/tools					 v0.0.0-20190816200558-6889da9d5479 \
	golang.org/x/tools					 v0.0.0-20190910044552-dd2b5c81c578 \
	golang.org/x/tools					 v0.0.0-20190911174233-4f2ddba30aff \
	golang.org/x/tools					 v0.0.0-20190916130336-e45ffcd953cc \
	golang.org/x/tools					 v0.0.0-20191012152004-8de300cfc20a \
	golang.org/x/tools					 v0.0.0-20191108193012-7d206e10da11 \
	golang.org/x/tools					 v0.0.0-20191113191852-77e3bb0ad9e7 \
	golang.org/x/tools					 v0.0.0-20191115202509-3a792d9c32b2 \
	golang.org/x/tools					 v0.0.0-20191119224855-298f0cb1881e \
	golang.org/x/tools					 v0.0.0-20191125144606-a911d9008d1f \
	golang.org/x/tools					 v0.0.0-20191130070609-6e064ea0cf2d \
	golang.org/x/tools					 v0.0.0-20191216173652-a0e659d51361 \
	golang.org/x/tools					 v0.0.0-20191227053925-7b8e75db28f4 \
	golang.org/x/tools					 v0.0.0-20200117161641-43d50277825c \
	golang.org/x/tools					 v0.0.0-20200117220505-0cba7a3a9ee9 \
	golang.org/x/tools					 v0.0.0-20200122220014-bf1340f18c4a \
	golang.org/x/tools					 v0.0.0-20200130002326-2f3ba24bd6e7 \
	golang.org/x/tools					 v0.0.0-20200204074204-1cc6d1ef6c74 \
	golang.org/x/tools					 v0.0.0-20200207183749-b753a1ba74fa \
	golang.org/x/tools					 v0.0.0-20200212150539-ea181f53ac56 \
	golang.org/x/tools					 v0.0.0-20200224181240-023911ca70b2 \
	golang.org/x/tools					 v0.0.0-20200227222343-706bc42d1f0d \
	golang.org/x/tools					 v0.0.0-20200304193943-95d2e580d8eb \
	golang.org/x/tools					 v0.0.0-20200312045724-11d5b4c81c7d \
	golang.org/x/tools					 v0.0.0-20200324003944-a576cf524670 \
	golang.org/x/tools					 v0.0.0-20200329025819-fd4102a86c65 \
	golang.org/x/tools					 v0.0.0-20200331025713-a30bf2db82d4 \
	golang.org/x/tools					 v0.0.0-20200414032229-332987a829c3 \
	golang.org/x/tools					 v0.0.0-20200501065659-ab2804fb9c9d \
	golang.org/x/tools					 v0.0.0-20200512131952-2bc93b1c0c88 \
	golang.org/x/tools					 v0.0.0-20200515010526-7d3b6ebf133d \
	golang.org/x/tools					 v0.0.0-20200618134242-20370b0cb4b2 \
	golang.org/x/tools					 v0.0.0-20200622203043-20e05c1c8ffa \
	golang.org/x/tools					 v0.0.0-20200624225443-88f3c62a19ff \
	golang.org/x/tools					 v0.0.0-20200625211823-6506e20df31f \
	golang.org/x/tools					 v0.0.0-20200724022722-7017fd6b1305 \
	golang.org/x/tools					 v0.0.0-20200729194436-6467de6f59a7 \
	golang.org/x/tools					 v0.0.0-20200804011535-6c149bb5ef0d \
	golang.org/x/tools					 v0.0.0-20200812195022-5ae4c3c160a0 \
	golang.org/x/tools					 v0.0.0-20200820010801-b793a1359eac \
	golang.org/x/tools					 v0.0.0-20200825202427-b303f430e36d \
	golang.org/x/tools					 v0.0.0-20200831203904-5a2aa26beb65 \
	golang.org/x/tools					 v0.0.0-20200904185747-39188db58858 \
	golang.org/x/tools					 v0.0.0-20200918232735-d647fc253266 \
	golang.org/x/tools					 v0.0.0-20201001104356-43ebab892c4c \
	golang.org/x/tools					 v0.0.0-20201002184944-ecd9fd270d5d \
	golang.org/x/tools					 v0.0.0-20201023174141-c8cfbd0f21e6 \
	golang.org/x/tools					 v0.0.0-20201028025901-8cd080b735b3 \
	golang.org/x/tools					 v0.0.0-20201110124207-079ba7bd75cd \
	golang.org/x/tools					 v0.0.0-20201201161351-ac6f37ff4c2a \
	golang.org/x/tools					 v0.0.0-20201208233053-a543418bbed2 \
	golang.org/x/tools					 v0.0.0-20201224043029-2b0845dc783e \
	golang.org/x/tools					 v0.0.0-20201230224404-63754364767c \
	golang.org/x/tools					 v0.0.0-20210105154028-b0ab187a4818 \
	golang.org/x/tools					 v0.0.0-20210108195828-e2f9c7f1fc8e \
	golang.org/x/tools					 v0.0.0-20210112230658-8b4aab62c064 \
	golang.org/x/tools					 v0.0.0-20210114065538-d78b04bdf963 \
	golang.org/x/tools					 v0.1.0 \
	golang.org/x/tools					 v0.1.1 \
	golang.org/x/tools					 v0.1.1-0.20210205202024-ef80cdb6ec6d \
	golang.org/x/tools					 v0.1.1-0.20210302220138-2ac05c832e1a \
	golang.org/x/tools					 v0.1.10 \
	golang.org/x/tools					 v0.1.11 \
	golang.org/x/tools					 v0.1.11-0.20220513221640-090b14e8501f \
	golang.org/x/tools					 v0.1.12-0.20220628192153-7743d1d949f1 \
	golang.org/x/tools					 v0.1.5 \
	golang.org/x/tools					 v0.1.7 \
	golang.org/x/tools					 v0.1.8 \
	golang.org/x/tools					 v0.1.9 \
	golang.org/x/tools					 v0.1.9-0.20211228192929-ee1ca4ffc4da \
	golang.org/x/xerrors					 v0.0.0-20190717185122-a985d3407aa7 \
	golang.org/x/xerrors					 v0.0.0-20191011141410-1b5146add898 \
	golang.org/x/xerrors					 v0.0.0-20191204190536-9bdfabe68543 \
	golang.org/x/xerrors					 v0.0.0-20200804184101-5ec99f83aff1 \
	google.golang.org/api					 v0.13.0 \
	google.golang.org/api					 v0.14.0 \
	google.golang.org/api					 v0.15.0 \
	google.golang.org/api					 v0.17.0 \
	google.golang.org/api					 v0.18.0 \
	google.golang.org/api					 v0.19.0 \
	google.golang.org/api					 v0.20.0 \
	google.golang.org/api					 v0.22.0 \
	google.golang.org/api					 v0.24.0 \
	google.golang.org/api					 v0.28.0 \
	google.golang.org/api					 v0.29.0 \
	google.golang.org/api					 v0.30.0 \
	google.golang.org/api					 v0.35.0 \
	google.golang.org/api					 v0.36.0 \
	google.golang.org/api					 v0.4.0 \
	google.golang.org/api					 v0.40.0 \
	google.golang.org/api					 v0.7.0 \
	google.golang.org/api					 v0.8.0 \
	google.golang.org/api					 v0.9.0 \
	google.golang.org/appengine				 v1.1.0 \
	google.golang.org/appengine				 v1.4.0 \
	google.golang.org/appengine				 v1.5.0 \
	google.golang.org/appengine				 v1.6.1 \
	google.golang.org/appengine				 v1.6.5 \
	google.golang.org/appengine				 v1.6.6 \
	google.golang.org/genproto				 v0.0.0-20180817151627-c66870c02cf8 \
	google.golang.org/genproto				 v0.0.0-20190307195333-5fe7a883aa19 \
	google.golang.org/genproto				 v0.0.0-20190418145605-e7d98fc518a7 \
	google.golang.org/genproto				 v0.0.0-20190425155659-357c62f0e4bb \
	google.golang.org/genproto				 v0.0.0-20190502173448-54afdca5d873 \
	google.golang.org/genproto				 v0.0.0-20190801165951-fa694d86fc64 \
	google.golang.org/genproto				 v0.0.0-20190819201941-24fa4b261c55 \
	google.golang.org/genproto				 v0.0.0-20190911173649-1774047e7e51 \
	google.golang.org/genproto				 v0.0.0-20191108220845-16a3f7862a1a \
	google.golang.org/genproto				 v0.0.0-20191115194625-c23dd37a84c9 \
	google.golang.org/genproto				 v0.0.0-20191216164720-4f79533eabd1 \
	google.golang.org/genproto				 v0.0.0-20191230161307-f3c370f40bfb \
	google.golang.org/genproto				 v0.0.0-20200115191322-ca5a22157cba \
	google.golang.org/genproto				 v0.0.0-20200122232147-0452cf42e150 \
	google.golang.org/genproto				 v0.0.0-20200204135345-fa8e72b47b90 \
	google.golang.org/genproto				 v0.0.0-20200212174721-66ed5ce911ce \
	google.golang.org/genproto				 v0.0.0-20200224152610-e50cd9704f63 \
	google.golang.org/genproto				 v0.0.0-20200228133532-8c2c7df3a383 \
	google.golang.org/genproto				 v0.0.0-20200305110556-506484158171 \
	google.golang.org/genproto				 v0.0.0-20200312145019-da6875a35672 \
	google.golang.org/genproto				 v0.0.0-20200331122359-1ee6d9798940 \
	google.golang.org/genproto				 v0.0.0-20200430143042-b979b6f78d84 \
	google.golang.org/genproto				 v0.0.0-20200511104702-f5ebc3bea380 \
	google.golang.org/genproto				 v0.0.0-20200515170657-fc4c6c6a6587 \
	google.golang.org/genproto				 v0.0.0-20200526211855-cb27e3aa2013 \
	google.golang.org/genproto				 v0.0.0-20200618031413-b414f8b61790 \
	google.golang.org/genproto				 v0.0.0-20200729003335-053ba62fc06f \
	google.golang.org/genproto				 v0.0.0-20200804131852-c06518451d9c \
	google.golang.org/genproto				 v0.0.0-20200825200019-8632dd797987 \
	google.golang.org/genproto				 v0.0.0-20200904004341-0bd0a958aa1d \
	google.golang.org/genproto				 v0.0.0-20201109203340-2640f1f9cdfb \
	google.golang.org/genproto				 v0.0.0-20201201144952-b05cb90ed32e \
	google.golang.org/genproto				 v0.0.0-20201210142538-e3217bee35cc \
	google.golang.org/genproto				 v0.0.0-20201214200347-8c77b98c765d \
	google.golang.org/genproto				 v0.0.0-20210108203827-ffc7fda8c3d7 \
	google.golang.org/genproto				 v0.0.0-20210226172003-ab064af71705 \
	google.golang.org/genproto				 v0.0.0-20210602131652-f16073e35f0c \
	google.golang.org/grpc					 v1.19.0 \
	google.golang.org/grpc					 v1.20.1 \
	google.golang.org/grpc					 v1.21.1 \
	google.golang.org/grpc					 v1.23.0 \
	google.golang.org/grpc					 v1.25.1 \
	google.golang.org/grpc					 v1.26.0 \
	google.golang.org/grpc					 v1.27.0 \
	google.golang.org/grpc					 v1.27.1 \
	google.golang.org/grpc					 v1.28.0 \
	google.golang.org/grpc					 v1.29.1 \
	google.golang.org/grpc					 v1.30.0 \
	google.golang.org/grpc					 v1.31.0 \
	google.golang.org/grpc					 v1.31.1 \
	google.golang.org/grpc					 v1.33.2 \
	google.golang.org/grpc					 v1.34.0 \
	google.golang.org/grpc					 v1.35.0 \
	google.golang.org/grpc					 v1.38.0 \
	google.golang.org/protobuf				 v0.0.0-20200109180630-ec00e32a8dfd \
	google.golang.org/protobuf				 v0.0.0-20200221191635-4d8936d0db64 \
	google.golang.org/protobuf				 v0.0.0-20200228230310-ab0ca4ff8a60 \
	google.golang.org/protobuf				 v1.20.1-0.20200309200217-e05f789c0967 \
	google.golang.org/protobuf				 v1.21.0 \
	google.golang.org/protobuf				 v1.22.0 \
	google.golang.org/protobuf				 v1.23.0 \
	google.golang.org/protobuf				 v1.23.1-0.20200526195155-81db48ad09cc \
	google.golang.org/protobuf				 v1.24.0 \
	google.golang.org/protobuf				 v1.25.0 \
	google.golang.org/protobuf				 v1.26.0 \
	google.golang.org/protobuf				 v1.26.0-rc.1 \
	google.golang.org/protobuf				 v1.28.0 \
	gopkg.in/check.v1					 v0.0.0-20161208181325-20d25e280405 \
	gopkg.in/check.v1					 v1.0.0-20180628173108-788fd7840127 \
	gopkg.in/check.v1					 v1.0.0-20190902080502-41f04d3bba15 \
	gopkg.in/ini.v1						 v1.66.6 \
	gopkg.in/yaml.v2					 v2.2.1 \
	gopkg.in/yaml.v2					 v2.2.2 \
	gopkg.in/yaml.v2					 v2.2.4 \
	gopkg.in/yaml.v2					 v2.2.5 \
	gopkg.in/yaml.v2					 v2.2.8 \
	gopkg.in/yaml.v2					 v2.3.0 \
	gopkg.in/yaml.v3					 v3.0.0-20200313102051-9f266ea9e77c \
	gopkg.in/yaml.v3					 v3.0.0-20210107192922-496545a6307b \
	honnef.co/go/tools					 v0.0.0-20190102054323-c2f93a96b099 \
	honnef.co/go/tools					 v0.0.0-20190106161140-3f1c8253044a \
	honnef.co/go/tools					 v0.0.0-20190418001031-e561f6794a2a \
	honnef.co/go/tools					 v0.0.0-20190523083050-ea95bdfd59fc \
	honnef.co/go/tools					 v0.0.1-2019.2.3 \
	honnef.co/go/tools					 v0.0.1-2020.1.3 \
	honnef.co/go/tools					 v0.0.1-2020.1.4
