MODGO_MODULES =	\
	cloud.google.com/go					 v0.51.0 \
	cloud.google.com/go/bigquery				 v1.3.0 \
	cloud.google.com/go/bigtable				 v1.2.0 \
	cloud.google.com/go/datastore				 v1.0.0 \
	cloud.google.com/go/pubsub				 v1.1.0 \
	cloud.google.com/go/storage				 v1.5.0 \
	collectd.org						 v0.3.0 \
	dmitri.shuralyov.com/gpu/mtl				 v0.0.0-20190408044501-666a987793e9 \
	github.com/!burnt!sushi/toml				 v0.3.1 \
	github.com/!burnt!sushi/xgb				 v0.0.0-20160522181843-27f122750802 \
	github.com/!d!a!t!a-!d!o!g/go-sqlmock			 v1.3.3 \
	github.com/!masterminds/goutils				 v1.1.1 \
	github.com/!masterminds/semver				 v1.5.0 \
	github.com/!masterminds/sprig				 v2.22.0+incompatible \
	github.com/!one!of!one/xxhash				 v1.2.2 \
	github.com/ajstarks/svgo				 v0.0.0-20180226025133-644b8db467af \
	github.com/alecthomas/template				 v0.0.0-20160405071501-a0175ee3bccc \
	github.com/alecthomas/units				 v0.0.0-20151022065526-2efee857e7cf \
	github.com/andreyvit/diff				 v0.0.0-20170406064948-c7f18ee00883 \
	github.com/apache/arrow/go/arrow			 v0.0.0-20191024131854-af6fa24be0db \
	github.com/benbjohnson/tmpl				 v1.1.0 \
	github.com/beorn7/perks					 v1.0.0 \
	github.com/bmizerany/pat				 v0.0.0-20170815010413-6226ea591a40 \
	github.com/c-bata/go-prompt				 v0.2.2 \
	github.com/census-instrumentation/opencensus-proto	 v0.2.1 \
	github.com/cespare/xxhash				 v1.1.0 \
	github.com/chzyer/logex					 v1.1.10 \
	github.com/chzyer/readline				 v0.0.0-20180603132655-2972be24d48e \
	github.com/chzyer/test					 v0.0.0-20180213035817-a1ea475d72b1 \
	github.com/client9/misspell				 v0.3.4 \
	github.com/dave/jennifer				 v1.2.0 \
	github.com/davecgh/go-spew				 v1.1.1 \
	github.com/dgrijalva/jwt-go/v4				 v4.0.0-preview1 \
	github.com/dgryski/go-bitstream				 v0.0.0-20180413035011-3522498ce2c8 \
	github.com/dustin/go-humanize				 v1.0.0 \
	github.com/eclipse/paho.mqtt.golang			 v1.2.0 \
	github.com/envoyproxy/go-control-plane			 v0.9.1-0.20191026205805-5f8ba28d4473 \
	github.com/envoyproxy/protoc-gen-validate		 v0.1.0 \
	github.com/fogleman/gg					 v1.2.1-0.20190220221249-0403632d5b90 \
	github.com/glycerine/go-unsnap-stream			 v0.0.0-20180323001048-9f0cb55181dd \
	github.com/glycerine/goconvey				 v0.0.0-20190410193231-58a59202ab31 \
	github.com/go-gl/glfw					 v0.0.0-20190409004039-e6da0acd62b1 \
	github.com/go-gl/glfw/v3.3/glfw				 v0.0.0-20191125211704-12ad95a8df72 \
	github.com/go-kit/kit					 v0.8.0 \
	github.com/go-logfmt/logfmt				 v0.4.0 \
	github.com/go-sql-driver/mysql				 v1.4.1 \
	github.com/go-stack/stack				 v1.8.0 \
	github.com/gofrs/uuid					 v3.3.0+incompatible \
	github.com/gogo/protobuf				 v1.3.2 \
	github.com/golang/freetype				 v0.0.0-20170609003504-e2365dfdc4a0 \
	github.com/golang/geo					 v0.0.0-20190916061304-5b978397cfec \
	github.com/golang/glog					 v0.0.0-20160126235308-23def4e6c14b \
	github.com/golang/groupcache				 v0.0.0-20191227052852-215e87163ea7 \
	github.com/golang/mock					 v1.3.1 \
	github.com/golang/protobuf				 v1.3.2 \
	github.com/golang/snappy				 v0.0.0-20180518054509-2e65f85255db \
	github.com/google/btree					 v1.0.0 \
	github.com/google/flatbuffers				 v1.11.0 \
	github.com/google/go-cmp				 v0.4.0 \
	github.com/google/martian				 v2.1.0+incompatible \
	github.com/google/pprof					 v0.0.0-20191218002539-d4f498aebedc \
	github.com/google/renameio				 v0.1.0 \
	github.com/google/uuid					 v1.2.0 \
	github.com/googleapis/gax-go/v2				 v2.0.5 \
	github.com/gopherjs/gopherjs				 v0.0.0-20181017120253-0766667cb4d1 \
	github.com/hashicorp/golang-lru				 v0.5.1 \
	github.com/huandu/xstrings				 v1.3.2 \
	github.com/ianlancetaylor/demangle			 v0.0.0-20181102032728-5e5cf60278f6 \
	github.com/imdario/mergo				 v0.3.12 \
	github.com/inconshreveable/mousetrap			 v1.0.0 \
	github.com/influxdata/flux				 v0.65.1 \
	github.com/influxdata/influxql				 v1.1.1-0.20200828144457-65d3ef77d385 \
	github.com/influxdata/line-protocol			 v0.0.0-20180522152040-32c6aa80de5e \
	github.com/influxdata/pkg-config			 v0.2.8 \
	github.com/influxdata/promql/v2				 v2.12.0 \
	github.com/influxdata/roaring				 v0.4.13-0.20180809181101-fc520f41fab6 \
	github.com/influxdata/tdigest				 v0.0.0-20181121200506-bf2b5ad3c0a9 \
	github.com/influxdata/usage-client			 v0.0.0-20160829180054-6d3895376368 \
	github.com/json-iterator/go				 v1.1.6 \
	github.com/jstemmer/go-junit-report			 v0.9.1 \
	github.com/jsternberg/zap-logfmt			 v1.0.0 \
	github.com/jtolds/gls					 v4.20.0+incompatible \
	github.com/julienschmidt/httprouter			 v1.2.0 \
	github.com/jung-kurt/gofpdf				 v1.0.3-0.20190309125859-24315acbbda5 \
	github.com/jwilder/encoding				 v0.0.0-20170811194829-b4e1701a28ef \
	github.com/kisielk/errcheck				 v1.5.0 \
	github.com/kisielk/gotool				 v1.0.0 \
	github.com/klauspost/compress				 v1.4.0 \
	github.com/klauspost/cpuid				 v0.0.0-20170728055534-ae7887de9fa5 \
	github.com/klauspost/crc32				 v0.0.0-20161016154125-cb6bfca970f6 \
	github.com/klauspost/pgzip				 v1.0.2-0.20170402124221-0bf5dcad4ada \
	github.com/konsorten/go-windows-terminal-sequences	 v1.0.1 \
	github.com/kr/logfmt					 v0.0.0-20140226030751-b84e30acd515 \
	github.com/kr/pretty					 v0.1.0 \
	github.com/kr/pty					 v1.1.1 \
	github.com/kr/text					 v0.1.0 \
	github.com/lib/pq					 v1.0.0 \
	github.com/mattn/go-colorable				 v0.0.9 \
	github.com/mattn/go-isatty				 v0.0.4 \
	github.com/mattn/go-runewidth				 v0.0.3 \
	github.com/mattn/go-sqlite3				 v1.11.0 \
	github.com/mattn/go-tty					 v0.0.0-20180907095812-13ff1204f104 \
	github.com/matttproud/golang_protobuf_extensions	 v1.0.1 \
	github.com/mitchellh/copystructure			 v1.1.1 \
	github.com/mitchellh/reflectwalk			 v1.0.1 \
	github.com/modern-go/concurrent				 v0.0.0-20180306012644-bacd9c7ef1dd \
	github.com/modern-go/reflect2				 v1.0.1 \
	github.com/mschoch/smat					 v0.0.0-20160514031455-90eadee771ae \
	github.com/mwitkow/go-conntrack				 v0.0.0-20161129095857-cc309e4a2223 \
	github.com/opentracing/opentracing-go			 v1.0.3-0.20180606204148-bd9c31933947 \
	github.com/paulbellamy/ratecounter			 v0.2.0 \
	github.com/peterh/liner					 v1.0.1-0.20180619022028-8c1271fcf47f \
	github.com/philhofer/fwd				 v1.0.0 \
	github.com/pierrec/lz4					 v2.0.5+incompatible \
	github.com/pkg/errors					 v0.9.1 \
	github.com/pkg/term					 v0.0.0-20180730021639-bffc007b7fd5 \
	github.com/pmezard/go-difflib				 v1.0.0 \
	github.com/prometheus/client_golang			 v1.0.0 \
	github.com/prometheus/client_model			 v0.0.0-20190812154241-14fe0d1b01d4 \
	github.com/prometheus/common				 v0.6.0 \
	github.com/prometheus/procfs				 v0.0.2 \
	github.com/retailnext/hllpp				 v1.0.1-0.20180308014038-101a6d2f8b52 \
	github.com/rogpeppe/go-internal				 v1.3.0 \
	github.com/segmentio/kafka-go				 v0.2.0 \
	github.com/sergi/go-diff				 v1.0.0 \
	github.com/sirupsen/logrus				 v1.2.0 \
	github.com/smartystreets/assertions			 v0.0.0-20180927180507-b2de0cb4f26d \
	github.com/smartystreets/goconvey			 v1.6.4 \
	github.com/spaolacci/murmur3				 v0.0.0-20180118202830-f09979ecbc72 \
	github.com/spf13/cast					 v1.3.0 \
	github.com/spf13/cobra					 v0.0.3 \
	github.com/spf13/pflag					 v1.0.3 \
	github.com/stretchr/objx				 v0.1.1 \
	github.com/stretchr/testify				 v1.7.0 \
	github.com/tinylib/msgp					 v1.0.2 \
	github.com/willf/bitset					 v1.1.3 \
	github.com/xlab/treeprint				 v0.0.0-20180616005107-d6fb6747feb6 \
	github.com/yuin/goldmark				 v1.2.1 \
	go.opencensus.io					 v0.22.2 \
	go.uber.org/atomic					 v1.5.1 \
	go.uber.org/multierr					 v1.4.0 \
	go.uber.org/tools					 v0.0.0-20190618225709-2cfd321de3ee \
	go.uber.org/zap						 v1.9.1 \
	golang.org/x/crypto					 v0.0.0-20210322153248-0c34fe9e7dc2 \
	golang.org/x/exp					 v0.0.0-20191227195350-da58074b4299 \
	golang.org/x/image					 v0.0.0-20190802002840-cff245a6509b \
	golang.org/x/lint					 v0.0.0-20191125180803-fdd1cda4f05f \
	golang.org/x/mobile					 v0.0.0-20190719004257-d2bd2a29d028 \
	golang.org/x/mod					 v0.3.0 \
	golang.org/x/net					 v0.0.0-20210226172049-e18ecbb05110 \
	golang.org/x/oauth2					 v0.0.0-20200107190931-bf48bf16ab8d \
	golang.org/x/sync					 v0.0.0-20201020160332-67f06af15bc9 \
	golang.org/x/sys					 v0.0.0-20201119102817-f84b799fce68 \
	golang.org/x/term					 v0.0.0-20201126162022-7de9c90e9dd1 \
	golang.org/x/text					 v0.3.3 \
	golang.org/x/time					 v0.0.0-20190308202827-9d24e82272b4 \
	golang.org/x/tools					 v0.0.0-20210106214847-113979e3529a \
	golang.org/x/xerrors					 v0.0.0-20200804184101-5ec99f83aff1 \
	gonum.org/v1/gonum					 v0.6.0 \
	gonum.org/v1/netlib					 v0.0.0-20190313105609-8cb42192e0e0 \
	gonum.org/v1/plot					 v0.0.0-20190515093506-e2840ee46a6b \
	google.golang.org/api					 v0.15.0 \
	google.golang.org/appengine				 v1.6.5 \
	google.golang.org/genproto				 v0.0.0-20200108215221-bd8f9a0ef82f \
	google.golang.org/grpc					 v1.26.0 \
	gopkg.in/alecthomas/kingpin.v2				 v2.2.6 \
	gopkg.in/check.v1					 v1.0.0-20180628173108-788fd7840127 \
	gopkg.in/errgo.v2					 v2.1.0 \
	gopkg.in/yaml.v2					 v2.3.0 \
	gopkg.in/yaml.v3					 v3.0.0-20200313102051-9f266ea9e77c \
	honnef.co/go/tools					 v0.0.1-2019.2.3 \
	rsc.io/binaryregexp					 v0.2.0 \
	rsc.io/pdf						 v0.1.1

MODGO_MODFILES =	\
	cloud.google.com/go			 v0.26.0 \
	cloud.google.com/go			 v0.34.0 \
	cloud.google.com/go			 v0.38.0 \
	cloud.google.com/go			 v0.43.0 \
	cloud.google.com/go			 v0.44.1 \
	cloud.google.com/go			 v0.44.2 \
	cloud.google.com/go			 v0.45.1 \
	cloud.google.com/go			 v0.46.3 \
	cloud.google.com/go			 v0.50.0 \
	cloud.google.com/go/bigquery		 v1.0.1 \
	cloud.google.com/go/pubsub		 v1.0.1 \
	cloud.google.com/go/storage		 v1.0.0 \
	github.com/!masterminds/semver		 v1.4.2 \
	github.com/beorn7/perks			 v0.0.0-20180321164747-3a771d992973 \
	github.com/davecgh/go-spew		 v1.1.0 \
	github.com/go-logfmt/logfmt		 v0.3.0 \
	github.com/gogo/protobuf		 v1.1.1 \
	github.com/gogo/protobuf		 v1.3.1 \
	github.com/golang/groupcache		 v0.0.0-20190702054246-869f871628b6 \
	github.com/golang/mock			 v1.1.1 \
	github.com/golang/mock			 v1.2.0 \
	github.com/golang/protobuf		 v1.2.0 \
	github.com/golang/protobuf		 v1.3.1 \
	github.com/google/btree			 v0.0.0-20180813153112-4030bb1f1f0c \
	github.com/google/go-cmp		 v0.2.0 \
	github.com/google/go-cmp		 v0.3.0 \
	github.com/google/go-cmp		 v0.3.1 \
	github.com/google/pprof			 v0.0.0-20181206194817-3ea8567a2e57 \
	github.com/google/pprof			 v0.0.0-20190515194954-54271f7e092f \
	github.com/googleapis/gax-go/v2		 v2.0.4 \
	github.com/hashicorp/golang-lru		 v0.5.0 \
	github.com/jstemmer/go-junit-report	 v0.0.0-20190106144839-af01ea7f8024 \
	github.com/kisielk/errcheck		 v1.2.0 \
	github.com/opentracing/opentracing-go	 v1.0.2 \
	github.com/pkg/errors			 v0.8.0 \
	github.com/pkg/errors			 v0.8.1 \
	github.com/prometheus/client_golang	 v0.9.1 \
	github.com/prometheus/client_model	 v0.0.0-20180712105110-5c3871d89910 \
	github.com/prometheus/client_model	 v0.0.0-20190129233127-fd36f4220a90 \
	github.com/prometheus/common		 v0.4.1 \
	github.com/prometheus/procfs		 v0.0.0-20181005140218-185b4288413d \
	github.com/segmentio/kafka-go		 v0.1.0 \
	github.com/stretchr/objx		 v0.1.0 \
	github.com/stretchr/testify		 v1.2.0 \
	github.com/stretchr/testify		 v1.2.2 \
	github.com/stretchr/testify		 v1.3.0 \
	github.com/stretchr/testify		 v1.4.0 \
	github.com/yuin/goldmark		 v1.1.27 \
	go.opencensus.io			 v0.21.0 \
	go.opencensus.io			 v0.22.0 \
	go.uber.org/atomic			 v1.3.2 \
	go.uber.org/atomic			 v1.5.0 \
	go.uber.org/multierr			 v1.1.0 \
	golang.org/x/crypto			 v0.0.0-20180904163835-0709b304e793 \
	golang.org/x/crypto			 v0.0.0-20190308221718-c2843e01d9a2 \
	golang.org/x/crypto			 v0.0.0-20190510104115-cbcb75029529 \
	golang.org/x/crypto			 v0.0.0-20190605123033-f99c8df09eb5 \
	golang.org/x/crypto			 v0.0.0-20191011191535-87dc89f01550 \
	golang.org/x/crypto			 v0.0.0-20200622213623-75b288015ac9 \
	golang.org/x/exp			 v0.0.0-20180321215751-8460e604b9de \
	golang.org/x/exp			 v0.0.0-20180807140117-3d87b88a115f \
	golang.org/x/exp			 v0.0.0-20190121172915-509febef88a4 \
	golang.org/x/exp			 v0.0.0-20190125153040-c74c464bbbf2 \
	golang.org/x/exp			 v0.0.0-20190306152737-a1d7652674e8 \
	golang.org/x/exp			 v0.0.0-20190510132918-efd6b22b2522 \
	golang.org/x/exp			 v0.0.0-20190829153037-c13cbed26979 \
	golang.org/x/exp			 v0.0.0-20191030013958-a1ab85dbe136 \
	golang.org/x/exp			 v0.0.0-20191129062945-2f5052295587 \
	golang.org/x/image			 v0.0.0-20180708004352-c73c2afc3b81 \
	golang.org/x/image			 v0.0.0-20190227222117-0694c2d4d067 \
	golang.org/x/lint			 v0.0.0-20181026193005-c67002cb31c3 \
	golang.org/x/lint			 v0.0.0-20190227174305-5b3e6a55c961 \
	golang.org/x/lint			 v0.0.0-20190301231843-5614ed5bae6f \
	golang.org/x/lint			 v0.0.0-20190313153728-d0100b6bd8b3 \
	golang.org/x/lint			 v0.0.0-20190409202823-959b441ac422 \
	golang.org/x/lint			 v0.0.0-20190909230951-414d861bb4ac \
	golang.org/x/lint			 v0.0.0-20190930215403-16217165b5de \
	golang.org/x/mobile			 v0.0.0-20190312151609-d3739f865fa6 \
	golang.org/x/mod			 v0.0.0-20190513183733-4bf6d317e70e \
	golang.org/x/mod			 v0.1.0 \
	golang.org/x/mod			 v0.1.1-0.20191105210325-c90efee705ee \
	golang.org/x/mod			 v0.2.0 \
	golang.org/x/net			 v0.0.0-20180724234803-3673e40ba225 \
	golang.org/x/net			 v0.0.0-20180826012351-8a410e7b638d \
	golang.org/x/net			 v0.0.0-20181114220301-adae6a3d119a \
	golang.org/x/net			 v0.0.0-20190108225652-1e06a53dbb7e \
	golang.org/x/net			 v0.0.0-20190213061140-3a22650c66bd \
	golang.org/x/net			 v0.0.0-20190311183353-d8887717615a \
	golang.org/x/net			 v0.0.0-20190404232315-eb5bcb51f2a3 \
	golang.org/x/net			 v0.0.0-20190501004415-9ce7a6920f09 \
	golang.org/x/net			 v0.0.0-20190503192946-f4e77d36d62c \
	golang.org/x/net			 v0.0.0-20190603091049-60506f45cf65 \
	golang.org/x/net			 v0.0.0-20190613194153-d28f0bde5980 \
	golang.org/x/net			 v0.0.0-20190620200207-3b0461eec859 \
	golang.org/x/net			 v0.0.0-20190724013045-ca1201d0de80 \
	golang.org/x/net			 v0.0.0-20191209160850-c0dbc17a3553 \
	golang.org/x/net			 v0.0.0-20200226121028-0de0cce0169b \
	golang.org/x/net			 v0.0.0-20201021035429-f5854403a974 \
	golang.org/x/oauth2			 v0.0.0-20180821212333-d2e6202438be \
	golang.org/x/oauth2			 v0.0.0-20190226205417-e64efc72b421 \
	golang.org/x/oauth2			 v0.0.0-20190604053449-0f29369cfe45 \
	golang.org/x/oauth2			 v0.0.0-20191202225959-858c2ad4c8b6 \
	golang.org/x/sync			 v0.0.0-20180314180146-1d60e4601c6f \
	golang.org/x/sync			 v0.0.0-20181108010431-42b317875d0f \
	golang.org/x/sync			 v0.0.0-20181221193216-37e7f081c4d4 \
	golang.org/x/sync			 v0.0.0-20190227155943-e225da77a7e6 \
	golang.org/x/sync			 v0.0.0-20190423024810-112230192c58 \
	golang.org/x/sync			 v0.0.0-20190911185100-cd5d95a43a6e \
	golang.org/x/sys			 v0.0.0-20180830151530-49385e6e1522 \
	golang.org/x/sys			 v0.0.0-20180905080454-ebe1bf3edb33 \
	golang.org/x/sys			 v0.0.0-20181116152217-5ac8a444bdc5 \
	golang.org/x/sys			 v0.0.0-20190215142949-d0b11bdaac8a \
	golang.org/x/sys			 v0.0.0-20190312061237-fead79001313 \
	golang.org/x/sys			 v0.0.0-20190412213103-97732733099d \
	golang.org/x/sys			 v0.0.0-20190502145724-3ef323f4f1fd \
	golang.org/x/sys			 v0.0.0-20190507160741-ecd444e8653b \
	golang.org/x/sys			 v0.0.0-20190606165138-5da285871e9c \
	golang.org/x/sys			 v0.0.0-20190624142023-c5567b49c5d0 \
	golang.org/x/sys			 v0.0.0-20190726091711-fc99dfbffb4e \
	golang.org/x/sys			 v0.0.0-20191204072324-ce4227a45e2e \
	golang.org/x/sys			 v0.0.0-20191228213918-04cbcbbfeed8 \
	golang.org/x/sys			 v0.0.0-20200107162124-548cf772de50 \
	golang.org/x/sys			 v0.0.0-20200930185726-fdedc70b468f \
	golang.org/x/text			 v0.3.0 \
	golang.org/x/text			 v0.3.1-0.20180807135948-17ff2d5776d2 \
	golang.org/x/text			 v0.3.2 \
	golang.org/x/time			 v0.0.0-20181108054448-85acf8d2951c \
	golang.org/x/tools			 v0.0.0-20180525024113-a5b4c53f6e8b \
	golang.org/x/tools			 v0.0.0-20180917221912-90fa682c2a6e \
	golang.org/x/tools			 v0.0.0-20181030221726-6c7e314b6563 \
	golang.org/x/tools			 v0.0.0-20190114222345-bf090417da8b \
	golang.org/x/tools			 v0.0.0-20190206041539-40960b6deb8e \
	golang.org/x/tools			 v0.0.0-20190226205152-f727befe758c \
	golang.org/x/tools			 v0.0.0-20190311212946-11955173bddd \
	golang.org/x/tools			 v0.0.0-20190312151545-0bb0c0a6e846 \
	golang.org/x/tools			 v0.0.0-20190312170243-e65039ee4138 \
	golang.org/x/tools			 v0.0.0-20190328211700-ab21143f2384 \
	golang.org/x/tools			 v0.0.0-20190425150028-36563e24a262 \
	golang.org/x/tools			 v0.0.0-20190506145303-2d16b83fe98c \
	golang.org/x/tools			 v0.0.0-20190524140312-2c0ae7006135 \
	golang.org/x/tools			 v0.0.0-20190606124116-d0a3d012864b \
	golang.org/x/tools			 v0.0.0-20190621195816-6e04913cbbac \
	golang.org/x/tools			 v0.0.0-20190628153133-6cdbf07be9d0 \
	golang.org/x/tools			 v0.0.0-20190816200558-6889da9d5479 \
	golang.org/x/tools			 v0.0.0-20190911174233-4f2ddba30aff \
	golang.org/x/tools			 v0.0.0-20191012152004-8de300cfc20a \
	golang.org/x/tools			 v0.0.0-20191029041327-9cc4af7d6b2c \
	golang.org/x/tools			 v0.0.0-20191029190741-b9c20aec41a5 \
	golang.org/x/tools			 v0.0.0-20191113191852-77e3bb0ad9e7 \
	golang.org/x/tools			 v0.0.0-20191115202509-3a792d9c32b2 \
	golang.org/x/tools			 v0.0.0-20191119224855-298f0cb1881e \
	golang.org/x/tools			 v0.0.0-20191125144606-a911d9008d1f \
	golang.org/x/tools			 v0.0.0-20191216173652-a0e659d51361 \
	golang.org/x/tools			 v0.0.0-20191227053925-7b8e75db28f4 \
	golang.org/x/tools			 v0.0.0-20200108203644-89082a384178 \
	golang.org/x/tools			 v0.0.0-20200619180055-7c47624df98f \
	golang.org/x/xerrors			 v0.0.0-20190717185122-a985d3407aa7 \
	golang.org/x/xerrors			 v0.0.0-20191011141410-1b5146add898 \
	golang.org/x/xerrors			 v0.0.0-20191204190536-9bdfabe68543 \
	gonum.org/v1/gonum			 v0.0.0-20180816165407-929014505bf4 \
	gonum.org/v1/gonum			 v0.0.0-20181121035319-3f7ecaa7e8ca \
	gonum.org/v1/netlib			 v0.0.0-20181029234149-ec6d1f5cefe6 \
	google.golang.org/api			 v0.13.0 \
	google.golang.org/api			 v0.14.0 \
	google.golang.org/api			 v0.4.0 \
	google.golang.org/api			 v0.7.0 \
	google.golang.org/api			 v0.8.0 \
	google.golang.org/api			 v0.9.0 \
	google.golang.org/appengine		 v1.1.0 \
	google.golang.org/appengine		 v1.4.0 \
	google.golang.org/appengine		 v1.5.0 \
	google.golang.org/appengine		 v1.6.1 \
	google.golang.org/genproto		 v0.0.0-20180817151627-c66870c02cf8 \
	google.golang.org/genproto		 v0.0.0-20190307195333-5fe7a883aa19 \
	google.golang.org/genproto		 v0.0.0-20190418145605-e7d98fc518a7 \
	google.golang.org/genproto		 v0.0.0-20190425155659-357c62f0e4bb \
	google.golang.org/genproto		 v0.0.0-20190502173448-54afdca5d873 \
	google.golang.org/genproto		 v0.0.0-20190716160619-c506a9f90610 \
	google.golang.org/genproto		 v0.0.0-20190801165951-fa694d86fc64 \
	google.golang.org/genproto		 v0.0.0-20190819201941-24fa4b261c55 \
	google.golang.org/genproto		 v0.0.0-20190911173649-1774047e7e51 \
	google.golang.org/genproto		 v0.0.0-20191108220845-16a3f7862a1a \
	google.golang.org/genproto		 v0.0.0-20191115194625-c23dd37a84c9 \
	google.golang.org/genproto		 v0.0.0-20191216164720-4f79533eabd1 \
	google.golang.org/genproto		 v0.0.0-20191230161307-f3c370f40bfb \
	google.golang.org/grpc			 v1.19.0 \
	google.golang.org/grpc			 v1.20.1 \
	google.golang.org/grpc			 v1.21.1 \
	google.golang.org/grpc			 v1.23.0 \
	gopkg.in/check.v1			 v0.0.0-20161208181325-20d25e280405 \
	gopkg.in/yaml.v2			 v2.2.1 \
	gopkg.in/yaml.v2			 v2.2.2 \
	honnef.co/go/tools			 v0.0.0-20190102054323-c2f93a96b099 \
	honnef.co/go/tools			 v0.0.0-20190106161140-3f1c8253044a \
	honnef.co/go/tools			 v0.0.0-20190418001031-e561f6794a2a \
	honnef.co/go/tools			 v0.0.0-20190523083050-ea95bdfd59fc

# those two modules replace versions that blow on OpenBSD
MODGO_MODULES += github.com/pkg/term		 v1.1.0
MODGO_MODULES += github.com/c-bata/go-prompt	 v0.2.5

# indirect dependencies dragged by previous
MODGO_MODULES += \
	github.com/mattn/go-colorable		 v0.1.4 \
	github.com/mattn/go-colorable		 v0.1.7 \
	github.com/mattn/go-isatty		 v0.0.8 \
	github.com/mattn/go-isatty		 v0.0.10 \
	github.com/mattn/go-isatty		 v0.0.12 \
	github.com/mattn/go-runewidth		 v0.0.6 \
	github.com/mattn/go-runewidth		 v0.0.9 \
	github.com/mattn/go-tty			 v0.0.3

MODGO_MODFILES += \
	golang.org/x/sys			 v0.0.0-20190222072716-a9d3bda3a223 \
	golang.org/x/sys			 v0.0.0-20191008105621-543471e840be \
	golang.org/x/sys			 v0.0.0-20191120155948-bd437916bb0e \
	golang.org/x/sys			 v0.0.0-20200116001909-b77594299b42 \
	golang.org/x/sys			 v0.0.0-20200223170610-d5e6a3e2c0ae \
	golang.org/x/sys			 v0.0.0-20200909081042-eff7692f9009 \
	golang.org/x/sys			 v0.0.0-20200918174421-af09f7315aff
